@@ -24,6 +24,7 @@ import (
 	"github.com/dolthub/dolt/go/cmd/dolt/commands"
 	"github.com/dolthub/dolt/go/cmd/dolt/commands/engine"
 	"github.com/dolthub/dolt/go/cmd/dolt/errhand"
+	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env/actions"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
@@ -78,7 +79,7 @@ func (cmd TagsCmd) Exec(ctx context.Context, commandStr string, args []string, d
 
 	if len(tables) == 0 {
 		var err error
-		tables, err = root.GetTableNames(ctx)
+		tables, err = root.GetTableNames(ctx, doltdb.DefaultSchemaName)
 
 		if err != nil {
 			return commands.HandleVErrAndExitCode(errhand.BuildDError("unable to get table names.").AddCause(err).Build(), usage)
@@ -100,7 +101,7 @@ func (cmd TagsCmd) Exec(ctx context.Context, commandStr string, args []string, d
 	rows := make([]sql.Row, 0)
 
 	for _, tableName := range tables {
-		table, foundTableKey, ok, err := root.GetTableInsensitive(ctx, tableName)
+		table, foundTableKey, ok, err := doltdb.GetTableInsensitive(ctx, root, tableName)
 
 		// Return an error if table is not found
 		if !ok {
