@@ -22,7 +22,6 @@ import (
 	"net"
 	"net/http"
 	"os"
-	"runtime"
 	"strconv"
 	"strings"
 	"time"
@@ -45,8 +44,10 @@ import (
 	"github.com/dolthub/dolt/go/cmd/dolt/commands/engine"
 	eventsapi "github.com/dolthub/dolt/go/gen/proto/dolt/services/eventsapi/v1alpha1"
 	remotesapi "github.com/dolthub/dolt/go/gen/proto/dolt/services/remotesapi/v1alpha1"
+	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/remotesrv"
+	"github.com/dolthub/dolt/go/libraries/doltcore/servercfg"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/binlogreplication"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/cluster"
@@ -76,7 +77,7 @@ var ErrCouldNotLockDatabase = goerrors.NewKind("database \"%s\" is locked by ano
 func Serve(
 	ctx context.Context,
 	version string,
-	serverConfig ServerConfig,
+	serverConfig servercfg.ServerConfig,
 	controller *svcs.Controller,
 	dEnv *env.DoltEnv,
 ) (startError error, closeError error) {
@@ -96,14 +97,14 @@ func Serve(
 }
 
 func ConfigureServices(
-	serverConfig ServerConfig,
+	serverConfig servercfg.ServerConfig,
 	controller *svcs.Controller,
 	version string,
 	dEnv *env.DoltEnv,
 ) {
 	ValidateConfigStep := &svcs.AnonService{
 		InitF: func(context.Context) error {
-			return ValidateConfig(serverConfig)
+			return servercfg.ValidateConfig(serverConfig)
 		},
 	}
 	controller.Register(ValidateConfigStep)
@@ -154,14 +155,25 @@ func ConfigureServices(
 
 	fs := dEnv.FS
 	InitDataDir := &svcs.AnonService{
-		InitF: func(context.Context) (err error) {
+		InitF: func(ctx context.Context) (err error) {
 			if len(serverConfig.DataDir()) > 0 && serverConfig.DataDir() != "." {
 				fs, err = dEnv.FS.WithWorkingDir(serverConfig.DataDir())
 				if err != nil {
 					return err
 				}
+				// If datadir has changed, then reload the DoltEnv to ensure its local
+				// configuration store gets configured correctly
 				dEnv.FS = fs
+				dEnv = env.Load(ctx, dEnv.GetUserHomeDir, fs, doltdb.LocalDirDoltDB, dEnv.Version)
+
+				// If the datadir has changed, then we need to load any persisted global variables
+				// from the new datadir's local configuration store
+				err = dsess.InitPersistedSystemVars(dEnv)
+				if err != nil {
+					logrus.Errorf("failed to load persisted global variables: %s\n", err.Error())
+				}
 			}
+			dEnv.Config.SetFailsafes(env.DefaultFailsafeConfig)
 			return nil
 		},
 	}
@@ -289,7 +301,7 @@ func ConfigureServices(
 					mysqlDb.AddSuperUser(ed, config.ServerUser, "%", config.ServerPass)
 				}
 			} else if !privsExist {
-				mysqlDb.AddSuperUser(ed, defaultUser, "%", defaultPass)
+				mysqlDb.AddSuperUser(ed, servercfg.DefaultUser, "%", servercfg.DefaultPass)
 			}
 			ed.Close()
 
@@ -514,15 +526,15 @@ func ConfigureServices(
 	var mySQLServer *server.Server
 	InitSQLServer := &svcs.AnonService{
 		InitF: func(context.Context) (err error) {
-			v, ok := serverConfig.(validatingServerConfig)
-			if ok && v.goldenMysqlConnectionString() != "" {
+			v, ok := serverConfig.(servercfg.ValidatingServerConfig)
+			if ok && v.GoldenMysqlConnectionString() != "" {
 				mySQLServer, err = server.NewServerWithHandler(
 					serverConf,
 					sqlEngine.GetUnderlyingEngine(),
 					newSessionBuilder(sqlEngine, serverConfig),
 					metListener,
 					func(h mysql.Handler) (mysql.Handler, error) {
-						return golden.NewValidatingHandler(h, v.goldenMysqlConnectionString(), logrus.StandardLogger())
+						return golden.NewValidatingHandler(h, v.GoldenMysqlConnectionString(), logrus.StandardLogger())
 					},
 				)
 			} else {
@@ -756,7 +768,7 @@ func (r *remotesapiAuth) ApiAuthorize(ctx context.Context, superUserRequired boo
 	return true, nil
 }
 
-func LoadClusterTLSConfig(cfg cluster.Config) (*tls.Config, error) {
+func LoadClusterTLSConfig(cfg servercfg.ClusterConfig) (*tls.Config, error) {
 	rcfg := cfg.RemotesAPIConfig()
 	if rcfg.TLSKey() == "" && rcfg.TLSCert() == "" {
 		return nil, nil
@@ -782,7 +794,7 @@ func portInUse(hostPort string) bool {
 	return false
 }
 
-func newSessionBuilder(se *engine.SqlEngine, config ServerConfig) server.SessionBuilder {
+func newSessionBuilder(se *engine.SqlEngine, config servercfg.ServerConfig) server.SessionBuilder {
 	userToSessionVars := make(map[string]map[string]string)
 	userVars := config.UserVars()
 	for _, curr := range userVars {
@@ -820,7 +832,7 @@ func newSessionBuilder(se *engine.SqlEngine, config ServerConfig) server.Session
 }
 
 // getConfigFromServerConfig processes ServerConfig and returns server.Config for sql-server.
-func getConfigFromServerConfig(serverConfig ServerConfig) (server.Config, error) {
+func getConfigFromServerConfig(serverConfig servercfg.ServerConfig) (server.Config, error) {
 	serverConf, err := handleProtocolAndAddress(serverConfig)
 	if err != nil {
 		return server.Config{}, err
@@ -831,14 +843,14 @@ func getConfigFromServerConfig(serverConfig ServerConfig) (server.Config, error)
 	readTimeout := time.Duration(serverConfig.ReadTimeout()) * time.Millisecond
 	writeTimeout := time.Duration(serverConfig.WriteTimeout()) * time.Millisecond
 
-	tlsConfig, err := LoadTLSConfig(serverConfig)
+	tlsConfig, err := servercfg.LoadTLSConfig(serverConfig)
 	if err != nil {
 		return server.Config{}, err
 	}
 
 	// if persist is 'load' we use currently set persisted global variable,
 	// else if 'ignore' we set persisted global variable to current value from serverConfig
-	if serverConfig.PersistenceBehavior() == loadPerisistentGlobals {
+	if serverConfig.PersistenceBehavior() == servercfg.LoadPerisistentGlobals {
 		serverConf, err = serverConf.NewConfig()
 		if err != nil {
 			return server.Config{}, err
@@ -864,7 +876,7 @@ func getConfigFromServerConfig(serverConfig ServerConfig) (server.Config, error)
 }
 
 // handleProtocolAndAddress returns new server.Config object with only Protocol and Address defined.
-func handleProtocolAndAddress(serverConfig ServerConfig) (server.Config, error) {
+func handleProtocolAndAddress(serverConfig servercfg.ServerConfig) (server.Config, error) {
 	serverConf := server.Config{Protocol: "tcp"}
 
 	portAsString := strconv.Itoa(serverConfig.Port())
@@ -875,7 +887,7 @@ func handleProtocolAndAddress(serverConfig ServerConfig) (server.Config, error)
 	}
 	serverConf.Address = hostPort
 
-	sock, useSock, err := checkForUnixSocket(serverConfig)
+	sock, useSock, err := servercfg.CheckForUnixSocket(serverConfig)
 	if err != nil {
 		return server.Config{}, err
 	}
@@ -886,25 +898,6 @@ func handleProtocolAndAddress(serverConfig ServerConfig) (server.Config, error)
 	return serverConf, nil
 }
 
-// checkForUnixSocket evaluates ServerConfig for whether the unix socket is to be used or not.
-// If user defined socket flag or host is 'localhost', it returns the unix socket file location
-// either user-defined or the default if it was not defined.
-func checkForUnixSocket(config ServerConfig) (string, bool, error) {
-	if config.Socket() != "" {
-		if runtime.GOOS == "windows" {
-			return "", false, fmt.Errorf("cannot define unix socket file on Windows")
-		}
-		return config.Socket(), true, nil
-	} else {
-		// if host is undefined or defined as "localhost" -> unix
-		if runtime.GOOS != "windows" && config.Host() == "localhost" {
-			return defaultUnixSocketFilePath, true, nil
-		}
-	}
-
-	return "", false, nil
-}
-
 func getEventSchedulerStatus(status string) (eventscheduler.SchedulerStatus, error) {
 	switch strings.ToLower(status) {
 	case "on", "1":
