@@ -25,6 +25,7 @@ import (
 
 	"github.com/dolthub/dolt/go/cmd/dolt/cli"
 	"github.com/dolthub/dolt/go/cmd/dolt/errhand"
+	eventsapi "github.com/dolthub/dolt/go/gen/proto/dolt/services/eventsapi/v1alpha1"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/utils/argparser"
@@ -72,6 +73,7 @@ func (cmd StatusCmd) RequiresRepo() bool {
 }
 
 var _ cli.RepoNotRequiredCommand = StatusCmd{}
+var _ cli.EventMonitoredCommand = StatusCmd{}
 
 // Name is returns the name of the Dolt cli command. This is what is used on the command line to invoke the command
 func (cmd StatusCmd) Name() string {
@@ -94,6 +96,10 @@ func (cmd StatusCmd) ArgParser() *argparser.ArgParser {
 	return ap
 }
 
+func (cmd StatusCmd) EventType() eventsapi.ClientEventType {
+	return eventsapi.ClientEventType_STATUS
+}
+
 // Exec executes the command
 func (cmd StatusCmd) Exec(ctx context.Context, commandStr string, args []string, _ *env.DoltEnv, cliCtx cli.CliContext) int {
 	// parse arguments
@@ -662,7 +668,7 @@ func getJsonDocumentColAsString(sqlCtx *sql.Context, col interface{}) (string, e
 	case string:
 		return v, nil
 	case types.JSONDocument:
-		text, err := v.ToString(sqlCtx)
+		text, err := v.JSONString()
 		if err != nil {
 			return "", err
 		}
