@@ -55,7 +55,7 @@ type CommitInfo struct {
 
 var fwtStageName = "fwt"
 
-func GetWorkingWithVErr(dEnv *env.DoltEnv) (*doltdb.RootValue, errhand.VerboseError) {
+func GetWorkingWithVErr(dEnv *env.DoltEnv) (doltdb.RootValue, errhand.VerboseError) {
 	working, err := dEnv.WorkingRoot(context.Background())
 
 	if err != nil {
@@ -65,7 +65,7 @@ func GetWorkingWithVErr(dEnv *env.DoltEnv) (*doltdb.RootValue, errhand.VerboseEr
 	return working, nil
 }
 
-func GetStagedWithVErr(dEnv *env.DoltEnv) (*doltdb.RootValue, errhand.VerboseError) {
+func GetStagedWithVErr(dEnv *env.DoltEnv) (doltdb.RootValue, errhand.VerboseError) {
 	staged, err := dEnv.StagedRoot(context.Background())
 
 	if err != nil {
@@ -75,7 +75,7 @@ func GetStagedWithVErr(dEnv *env.DoltEnv) (*doltdb.RootValue, errhand.VerboseErr
 	return staged, nil
 }
 
-func UpdateWorkingWithVErr(dEnv *env.DoltEnv, updatedRoot *doltdb.RootValue) errhand.VerboseError {
+func UpdateWorkingWithVErr(dEnv *env.DoltEnv, updatedRoot doltdb.RootValue) errhand.VerboseError {
 	err := dEnv.UpdateWorkingRoot(context.Background(), updatedRoot)
 
 	switch err {
@@ -789,3 +789,32 @@ func HandleVErrAndExitCode(verr errhand.VerboseError, usage cli.UsagePrinter) in
 
 	return 0
 }
+
+// HasLocalChanges compares the working and staged hash against the head hash to determine if there are uncommitted changes.
+func HasLocalChanges(ctx context.Context, dEnv *env.DoltEnv) (bool, error) {
+	hRoot, err := dEnv.HeadRoot(ctx)
+	if err != nil {
+		return false, err
+	}
+	wRoot, err := dEnv.WorkingRoot(ctx)
+	if err != nil {
+		return false, err
+	}
+	sRoot, err := dEnv.StagedRoot(ctx)
+	if err != nil {
+		return false, err
+	}
+	hHash, err := hRoot.HashOf()
+	if err != nil {
+		return false, err
+	}
+	wHash, err := wRoot.HashOf()
+	if err != nil {
+		return false, err
+	}
+	sHash, err := sRoot.HashOf()
+	if err != nil {
+		return false, err
+	}
+	return !hHash.Equal(wHash) || !hHash.Equal(sHash), nil
+}
