@@ -24,7 +24,6 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb/durable"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
-	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlfmt"
 	"github.com/dolthub/dolt/go/libraries/utils/set"
 	"github.com/dolthub/dolt/go/store/prolly/tree"
 	"github.com/dolthub/dolt/go/store/types"
@@ -39,6 +38,8 @@ const (
 	RemovedTable
 )
 
+const DBPrefix = "__DATABASE__"
+
 type TableInfo struct {
 	Name       string
 	Sch        schema.Schema
@@ -110,7 +111,7 @@ func GetStagedUnstagedTableDeltas(ctx context.Context, roots doltdb.Roots) (stag
 
 // GetTableDeltas returns a slice of TableDelta objects for each table that changed between fromRoot and toRoot.
 // It matches tables across roots by finding Schemas with Column tags in common.
-func GetTableDeltas(ctx context.Context, fromRoot, toRoot *doltdb.RootValue) (deltas []TableDelta, err error) {
+func GetTableDeltas(ctx context.Context, fromRoot, toRoot doltdb.RootValue) (deltas []TableDelta, err error) {
 	fromVRW := fromRoot.VRW()
 	fromNS := fromRoot.NodeStore()
 	toVRW := toRoot.VRW()
@@ -182,6 +183,25 @@ func GetTableDeltas(ctx context.Context, fromRoot, toRoot *doltdb.RootValue) (de
 		return nil, err
 	}
 
+	fromColl, err := fromRoot.GetCollation(ctx)
+	if err != nil {
+		return nil, err
+	}
+	toColl, err := toRoot.GetCollation(ctx)
+	if err != nil {
+		return nil, err
+	}
+	if fromColl != toColl {
+		sqlCtx, ok := ctx.(*sql.Context)
+		if ok {
+			dbName := DBPrefix + sqlCtx.GetCurrentDatabase()
+			deltas = append(deltas, TableDelta{
+				FromName: dbName,
+				ToName:   dbName,
+			})
+		}
+	}
+
 	// Make sure we always return the same order of deltas
 	sort.Slice(deltas, func(i, j int) bool {
 		if deltas[i].FromName == deltas[j].FromName {
@@ -193,10 +213,10 @@ func GetTableDeltas(ctx context.Context, fromRoot, toRoot *doltdb.RootValue) (de
 	return deltas, nil
 }
 
-func getFkParentSchs(ctx context.Context, root *doltdb.RootValue, fks ...doltdb.ForeignKey) (map[string]schema.Schema, error) {
+func getFkParentSchs(ctx context.Context, root doltdb.RootValue, fks ...doltdb.ForeignKey) (map[string]schema.Schema, error) {
 	schs := make(map[string]schema.Schema)
 	for _, toFk := range fks {
-		toRefTable, _, ok, err := root.GetTableInsensitive(ctx, toFk.ReferencedTableName)
+		toRefTable, _, ok, err := doltdb.GetTableInsensitive(ctx, root, toFk.ReferencedTableName)
 		if err != nil {
 			return nil, err
 		}
@@ -346,6 +366,11 @@ func (td TableDelta) HasHashChanged() (bool, error) {
 // HasSchemaChanged returns true if the table schema has changed between the
 // fromRoot and toRoot.
 func (td TableDelta) HasSchemaChanged(ctx context.Context) (bool, error) {
+	// Database collation change is a schema change
+	if td.FromTable == nil && td.ToTable == nil {
+		return true, nil
+	}
+
 	if td.IsAdd() || td.IsDrop() {
 		return true, nil
 	}
@@ -368,6 +393,11 @@ func (td TableDelta) HasSchemaChanged(ctx context.Context) (bool, error) {
 }
 
 func (td TableDelta) HasDataChanged(ctx context.Context) (bool, error) {
+	// Database collation change is not a data change
+	if td.FromTable == nil && td.ToTable == nil {
+		return false, nil
+	}
+
 	if td.IsAdd() {
 		isEmpty, err := isTableDataEmpty(ctx, td.ToTable)
 		if err != nil {
@@ -424,6 +454,13 @@ func (td TableDelta) HasFKChanges() bool {
 		return true
 	}
 
+	if td.FromFks == nil && td.ToFks == nil {
+		return false
+	}
+	if td.FromFksParentSch == nil && td.ToFksParentSch == nil {
+		return false
+	}
+
 	sort.Slice(td.FromFks, func(i, j int) bool {
 		return td.FromFks[i].Name < td.FromFks[j].Name
 	})
@@ -562,56 +599,20 @@ func (td TableDelta) GetRowData(ctx context.Context) (from, to durable.Index, er
 	if td.FromTable != nil {
 		from, err = td.FromTable.GetRowData(ctx)
 		if err != nil {
-			return from, to, err
+			return nil, nil, err
 		}
-	} else {
-		// If there is no |FromTable| use the |ToTable|'s schema to make the index.
-		from, _ = durable.NewEmptyIndex(ctx, td.FromVRW, td.FromNodeStore, td.ToSch)
 	}
 
 	if td.ToTable != nil {
 		to, err = td.ToTable.GetRowData(ctx)
 		if err != nil {
-			return from, to, err
+			return nil, nil, err
 		}
-	} else {
-		// If there is no |ToTable| use the |FromTable|'s schema to make the index.
-		to, _ = durable.NewEmptyIndex(ctx, td.ToVRW, td.ToNodeStore, td.FromSch)
 	}
 
 	return from, to, nil
 }
 
-// GetDataDiffStatement returns any data diff in SQL statements for given table including INSERT, UPDATE and DELETE row statements.
-func GetDataDiffStatement(tableName string, sch schema.Schema, row sql.Row, rowDiffType ChangeType, colDiffTypes []ChangeType) (string, error) {
-	if len(row) != len(colDiffTypes) {
-		return "", fmt.Errorf("expected the same size for columns and diff types, got %d and %d", len(row), len(colDiffTypes))
-	}
-
-	switch rowDiffType {
-	case Added:
-		return sqlfmt.SqlRowAsInsertStmt(row, tableName, sch)
-	case Removed:
-		return sqlfmt.SqlRowAsDeleteStmt(row, tableName, sch, 0)
-	case ModifiedNew:
-		updatedCols := set.NewEmptyStrSet()
-		for i, diffType := range colDiffTypes {
-			if diffType != None {
-				updatedCols.Add(sch.GetAllCols().GetByIndex(i).Name)
-			}
-		}
-		if updatedCols.Size() == 0 {
-			return "", nil
-		}
-		return sqlfmt.SqlRowAsUpdateStmt(row, tableName, sch, updatedCols)
-	case ModifiedOld:
-		// do nothing, we only issue UPDATE for ModifiedNew
-		return "", nil
-	default:
-		return "", fmt.Errorf("unexpected row diff type: %v", rowDiffType)
-	}
-}
-
 // WorkingSetContainsOnlyIgnoredTables returns true if all changes in working set are ignored tables.
 // Otherwise, if there are any non-ignored changes, returns false.
 // Note that only unstaged tables are subject to dolt_ignore (this is consistent with what git does.)
