@@ -52,7 +52,7 @@ var (
 )
 
 var (
-	errNbfUnkown      = fmt.Errorf("unknown NomsBinFormat")
+	errNbfUnknown     = fmt.Errorf("unknown NomsBinFormat")
 	errNbfUnsupported = fmt.Errorf("operation unsupported for NomsBinFormat")
 )
 
@@ -106,7 +106,7 @@ type Table interface {
 	SetAutoIncrement(ctx context.Context, val uint64) (Table, error)
 
 	// DebugString returns the table contents for debugging purposes
-	DebugString(ctx context.Context) string
+	DebugString(ctx context.Context, ns tree.NodeStore) string
 }
 
 type nomsTable struct {
@@ -615,7 +615,7 @@ func (t nomsTable) SetAutoIncrement(ctx context.Context, val uint64) (Table, err
 	return nomsTable{t.vrw, t.ns, st}, nil
 }
 
-func (t nomsTable) DebugString(ctx context.Context) string {
+func (t nomsTable) DebugString(ctx context.Context, ns tree.NodeStore) string {
 	var buf bytes.Buffer
 	err := types.WriteEncodedValue(ctx, &buf, t.tableStruct)
 	if err != nil {
@@ -685,18 +685,18 @@ type doltDevTable struct {
 	msg *serial.Table
 }
 
-func (t doltDevTable) DebugString(ctx context.Context) string {
+func (t doltDevTable) DebugString(ctx context.Context, ns tree.NodeStore) string {
 	rows, err := t.GetTableRows(ctx)
 	if err != nil {
 		panic(err)
 	}
 
-	m := ProllyMapFromIndex(rows)
-	var b bytes.Buffer
-	m.WalkNodes(ctx, func(ctx context.Context, nd tree.Node) error {
-		return tree.OutputProllyNode(&b, nd)
-	})
-	return b.String()
+	schema, err := t.GetSchema(ctx)
+	if err != nil {
+		panic(err)
+	}
+
+	return rows.DebugString(ctx, ns, schema)
 }
 
 var _ Table = doltDevTable{}
@@ -897,7 +897,10 @@ func (t doltDevTable) SetIndexes(ctx context.Context, indexes IndexSet) (Table,
 }
 
 func (t doltDevTable) GetConflicts(ctx context.Context) (conflict.ConflictSchema, ConflictIndex, error) {
-	conflicts := t.msg.Conflicts(nil)
+	conflicts, err := t.msg.TryConflicts(nil)
+	if err != nil {
+		return conflict.ConflictSchema{}, nil, err
+	}
 
 	ouraddr := hash.New(conflicts.OurSchemaBytes())
 	theiraddr := hash.New(conflicts.TheirSchemaBytes())
@@ -997,7 +1000,10 @@ func (t doltDevTable) SetArtifacts(ctx context.Context, artifacts ArtifactIndex)
 
 func (t doltDevTable) HasConflicts(ctx context.Context) (bool, error) {
 
-	conflicts := t.msg.Conflicts(nil)
+	conflicts, err := t.msg.TryConflicts(nil)
+	if err != nil {
+		return false, err
+	}
 	addr := hash.New(conflicts.OurSchemaBytes())
 	return !addr.IsEmpty(), nil
 }
@@ -1023,7 +1029,10 @@ func (t doltDevTable) SetConflicts(ctx context.Context, sch conflict.ConflictSch
 	}
 
 	msg := t.clone()
-	cmsg := msg.Conflicts(nil)
+	cmsg, err := msg.TryConflicts(nil)
+	if err != nil {
+		return nil, err
+	}
 	copy(cmsg.DataBytes(), conflictsAddr[:])
 	copy(cmsg.OurSchemaBytes(), ouraddr[:])
 	copy(cmsg.TheirSchemaBytes(), theiraddr[:])
@@ -1034,7 +1043,10 @@ func (t doltDevTable) SetConflicts(ctx context.Context, sch conflict.ConflictSch
 
 func (t doltDevTable) ClearConflicts(ctx context.Context) (Table, error) {
 	msg := t.clone()
-	conflicts := msg.Conflicts(nil)
+	conflicts, err := msg.TryConflicts(nil)
+	if err != nil {
+		return nil, err
+	}
 	var emptyhash hash.Hash
 	copy(conflicts.DataBytes(), emptyhash[:])
 	copy(conflicts.OurSchemaBytes(), emptyhash[:])
@@ -1110,7 +1122,10 @@ func (t doltDevTable) fields() (serialTableFields, error) {
 	}
 	ns := t.ns
 
-	conflicts := t.msg.Conflicts(nil)
+	conflicts, err := t.msg.TryConflicts(nil)
+	if err != nil {
+		return serialTableFields{}, err
+	}
 	am, err := prolly.NewAddressMap(node, ns)
 	if err != nil {
 		return serialTableFields{}, err
