@@ -83,8 +83,8 @@ func IsNonAlterableSystemTable(name string) bool {
 }
 
 // GetNonSystemTableNames gets non-system table names
-func GetNonSystemTableNames(ctx context.Context, root *RootValue) ([]string, error) {
-	tn, err := root.GetTableNames(ctx)
+func GetNonSystemTableNames(ctx context.Context, root RootValue) ([]string, error) {
+	tn, err := root.GetTableNames(ctx, DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -96,7 +96,7 @@ func GetNonSystemTableNames(ctx context.Context, root *RootValue) ([]string, err
 }
 
 // GetSystemTableNames gets system table names
-func GetSystemTableNames(ctx context.Context, root *RootValue) ([]string, error) {
+func GetSystemTableNames(ctx context.Context, root RootValue) ([]string, error) {
 	p, err := GetPersistedSystemTables(ctx, root)
 	if err != nil {
 		return nil, err
@@ -114,8 +114,8 @@ func GetSystemTableNames(ctx context.Context, root *RootValue) ([]string, error)
 }
 
 // GetPersistedSystemTables returns table names of all persisted system tables.
-func GetPersistedSystemTables(ctx context.Context, root *RootValue) ([]string, error) {
-	tn, err := root.GetTableNames(ctx)
+func GetPersistedSystemTables(ctx context.Context, root RootValue) ([]string, error) {
+	tn, err := root.GetTableNames(ctx, DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -124,10 +124,10 @@ func GetPersistedSystemTables(ctx context.Context, root *RootValue) ([]string, e
 }
 
 // GetGeneratedSystemTables returns table names of all generated system tables.
-func GetGeneratedSystemTables(ctx context.Context, root *RootValue) ([]string, error) {
+func GetGeneratedSystemTables(ctx context.Context, root RootValue) ([]string, error) {
 	s := set.NewStrSet(generatedSystemTables)
 
-	tn, err := root.GetTableNames(ctx)
+	tn, err := root.GetTableNames(ctx, DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -140,7 +140,7 @@ func GetGeneratedSystemTables(ctx context.Context, root *RootValue) ([]string, e
 }
 
 // GetAllTableNames returns table names for all persisted and generated tables.
-func GetAllTableNames(ctx context.Context, root *RootValue) ([]string, error) {
+func GetAllTableNames(ctx context.Context, root RootValue) ([]string, error) {
 	n, err := GetNonSystemTableNames(ctx, root)
 	if err != nil {
 		return nil, err
