@@ -85,6 +85,11 @@ func NewTable(ctx context.Context, vrw types.ValueReadWriter, ns tree.NodeStore,
 	return &Table{table: dt}, nil
 }
 
+// NewTableFromDurable creates a table from the given durable object.
+func NewTableFromDurable(table durable.Table) *Table {
+	return &Table{table: table}
+}
+
 func NewEmptyTable(ctx context.Context, vrw types.ValueReadWriter, ns tree.NodeStore, sch schema.Schema) (*Table, error) {
 	rows, err := durable.NewEmptyIndex(ctx, vrw, ns, sch)
 	if err != nil {
@@ -330,7 +335,7 @@ func tableFromRootIsh(ctx context.Context, vrw types.ValueReadWriter, ns tree.No
 	if err != nil {
 		return nil, false, err
 	}
-	tbl, ok, err := rv.GetTable(ctx, tblName)
+	tbl, ok, err := rv.GetTable(ctx, TableName{Name: tblName})
 	if err != nil {
 		return nil, false, err
 	}
@@ -572,7 +577,7 @@ func (t *Table) GetNomsIndexRowData(ctx context.Context, indexName string) (type
 		return types.EmptyMap, err
 	}
 
-	idx, err := indexes.GetIndex(ctx, sch, indexName)
+	idx, err := indexes.GetIndex(ctx, sch, nil, indexName)
 	if err != nil {
 		return types.EmptyMap, err
 	}
@@ -592,7 +597,7 @@ func (t *Table) GetIndexRowData(ctx context.Context, indexName string) (durable.
 		return nil, err
 	}
 
-	return indexes.GetIndex(ctx, sch, indexName)
+	return indexes.GetIndex(ctx, sch, nil, indexName)
 }
 
 // SetIndexRows replaces the current row data for the given index and returns an updated Table.
