@@ -46,7 +46,7 @@ func CheckoutTables(ctx context.Context, roots doltdb.Roots, tables []string) (d
 func MoveTablesFromHeadToWorking(ctx context.Context, roots doltdb.Roots, tbls []string) (doltdb.Roots, error) {
 	var unknownTbls []string
 	for _, tblName := range tbls {
-		tbl, ok, err := roots.Staged.GetTable(ctx, tblName)
+		tbl, ok, err := roots.Staged.GetTable(ctx, doltdb.TableName{Name: tblName})
 		if err != nil {
 			return doltdb.Roots{}, err
 		}
@@ -56,7 +56,7 @@ func MoveTablesFromHeadToWorking(ctx context.Context, roots doltdb.Roots, tbls [
 		}
 
 		if !ok {
-			tbl, ok, err = roots.Head.GetTable(ctx, tblName)
+			tbl, ok, err = roots.Head.GetTable(ctx, doltdb.TableName{Name: tblName})
 			if err != nil {
 				return doltdb.Roots{}, err
 			}
@@ -72,7 +72,7 @@ func MoveTablesFromHeadToWorking(ctx context.Context, roots doltdb.Roots, tbls [
 			}
 		}
 
-		roots.Working, err = roots.Working.PutTable(ctx, tblName, tbl)
+		roots.Working, err = roots.Working.PutTable(ctx, doltdb.TableName{Name: tblName}, tbl)
 		if err != nil {
 			return doltdb.Roots{}, err
 		}
@@ -102,7 +102,7 @@ func MoveTablesFromHeadToWorking(ctx context.Context, roots doltdb.Roots, tbls [
 
 // RootsForBranch returns the roots needed for a branch checkout. |roots.Head| should be the pre-checkout head. The
 // returned roots struct has |Head| set to |branchRoot|.
-func RootsForBranch(ctx context.Context, roots doltdb.Roots, branchRoot *doltdb.RootValue, force bool) (doltdb.Roots, error) {
+func RootsForBranch(ctx context.Context, roots doltdb.Roots, branchRoot doltdb.RootValue, force bool) (doltdb.Roots, error) {
 	conflicts := set.NewStrSet([]string{})
 	if roots.Head == nil {
 		roots.Working = branchRoot
@@ -229,7 +229,7 @@ func CleanOldWorkingSet(
 }
 
 // BranchHeadRoot returns the root value at the branch head with the name given
-func BranchHeadRoot(ctx context.Context, db *doltdb.DoltDB, brName string) (*doltdb.RootValue, error) {
+func BranchHeadRoot(ctx context.Context, db *doltdb.DoltDB, brName string) (doltdb.RootValue, error) {
 	cs, err := doltdb.NewCommitSpec(brName)
 	if err != nil {
 		return nil, doltdb.RootValueUnreadable{RootType: doltdb.HeadRoot, Cause: err}
@@ -256,9 +256,9 @@ func BranchHeadRoot(ctx context.Context, db *doltdb.DoltDB, brName string) (*dol
 // When moving between branches, changes in the working set should travel with you.
 // Working set changes cannot be moved if the table differs between the old and new head,
 // in this case, we throw a conflict and error (as per Git).
-func moveModifiedTables(ctx context.Context, oldRoot, newRoot, changedRoot *doltdb.RootValue, conflicts *set.StrSet, force bool) (map[string]hash.Hash, error) {
+func moveModifiedTables(ctx context.Context, oldRoot, newRoot, changedRoot doltdb.RootValue, conflicts *set.StrSet, force bool) (map[string]hash.Hash, error) {
 	resultMap := make(map[string]hash.Hash)
-	tblNames, err := newRoot.GetTableNames(ctx)
+	tblNames, err := newRoot.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -290,7 +290,7 @@ func moveModifiedTables(ctx context.Context, oldRoot, newRoot, changedRoot *dolt
 		}
 	}
 
-	tblNames, err = changedRoot.GetTableNames(ctx)
+	tblNames, err = changedRoot.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -321,7 +321,7 @@ func moveModifiedTables(ctx context.Context, oldRoot, newRoot, changedRoot *dolt
 }
 
 // moveForeignKeys returns the foreign key collection that should be used for the new working set.
-func moveForeignKeys(ctx context.Context, oldRoot, newRoot, changedRoot *doltdb.RootValue, force bool) (*doltdb.ForeignKeyCollection, error) {
+func moveForeignKeys(ctx context.Context, oldRoot, newRoot, changedRoot doltdb.RootValue, force bool) (*doltdb.ForeignKeyCollection, error) {
 	oldFks, err := oldRoot.GetForeignKeyCollection(ctx)
 	if err != nil {
 		return nil, err
@@ -369,16 +369,16 @@ func moveForeignKeys(ctx context.Context, oldRoot, newRoot, changedRoot *doltdb.
 func mergeForeignKeyChanges(
 	ctx context.Context,
 	oldFks *doltdb.ForeignKeyCollection,
-	newRoot *doltdb.RootValue,
+	newRoot doltdb.RootValue,
 	newFks *doltdb.ForeignKeyCollection,
-	changedRoot *doltdb.RootValue,
+	changedRoot doltdb.RootValue,
 	changedFks *doltdb.ForeignKeyCollection,
 	force bool,
 ) (*doltdb.ForeignKeyCollection, error) {
 	fksByTable := make(map[string][]doltdb.ForeignKey)
 
 	conflicts := set.NewEmptyStrSet()
-	tblNames, err := newRoot.GetTableNames(ctx)
+	tblNames, err := newRoot.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -412,7 +412,7 @@ func mergeForeignKeyChanges(
 		}
 	}
 
-	tblNames, err = changedRoot.GetTableNames(ctx)
+	tblNames, err = changedRoot.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -455,8 +455,8 @@ func mergeForeignKeyChanges(
 
 // writeTableHashes writes new table hash values for the root given and returns it.
 // This is an inexpensive and convenient way of replacing all the tables at once.
-func writeTableHashes(ctx context.Context, head *doltdb.RootValue, tblHashes map[string]hash.Hash) (*doltdb.RootValue, error) {
-	names, err := head.GetTableNames(ctx)
+func writeTableHashes(ctx context.Context, head doltdb.RootValue, tblHashes map[string]hash.Hash) (doltdb.RootValue, error) {
+	names, err := head.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
