@@ -26,7 +26,7 @@ import (
 
 type c struct {
 	ddb       *doltdb.DoltDB
-	commit    *doltdb.Commit
+	commit    *doltdb.OptionalCommit
 	meta      *datas.CommitMeta
 	hash      hash.Hash
 	height    uint64
@@ -63,10 +63,27 @@ func (q *q) Swap(i, j int) {
 	q.pending[i], q.pending[j] = q.pending[j], q.pending[i]
 }
 
+// Less returns true if the commit at index i is "less" than the commit at index j. It may be the case that you are comparing
+// two resolved commits, two ghost commits, or a resolved commit and a ghost commit. Ghost commits will always be "less" than
+// resolved commits. If both commits are resolved, then the commit with the higher height is "less". If the heights are equal, then
+// the commit with the newer timestamp is "less". Finally if both commits are ghost commits, we don't really have enough
+// information to compare on, so we just compare the hashes to ensure that the results are stable.
 func (q *q) Less(i, j int) bool {
+	_, okI := q.pending[i].commit.ToCommit()
+	_, okJ := q.pending[i].commit.ToCommit()
+
+	if !okI && okJ {
+		return true
+	} else if okI && !okJ {
+		return false
+	} else if !okI && !okJ {
+		return q.pending[i].hash.String() < q.pending[j].hash.String()
+	}
+
 	if q.pending[i].height > q.pending[j].height {
 		return true
 	}
+
 	if q.pending[i].height == q.pending[j].height {
 		return q.pending[i].meta.UserTimestamp > q.pending[j].meta.UserTimestamp
 	}
@@ -110,7 +127,7 @@ func (q *q) SetInvisible(ctx context.Context, ddb *doltdb.DoltDB, id hash.Hash)
 	return nil
 }
 
-func load(ctx context.Context, ddb *doltdb.DoltDB, h hash.Hash) (*doltdb.Commit, error) {
+func load(ctx context.Context, ddb *doltdb.DoltDB, h hash.Hash) (*doltdb.OptionalCommit, error) {
 	cs, err := doltdb.NewCommitSpec(h.String())
 	if err != nil {
 		return nil, err
@@ -127,20 +144,26 @@ func (q *q) Get(ctx context.Context, ddb *doltdb.DoltDB, id hash.Hash) (*c, erro
 		return l, nil
 	}
 
-	l, err := load(ctx, ddb, id)
-	if err != nil {
-		return nil, err
-	}
-	h, err := l.Height()
-	if err != nil {
-		return nil, err
-	}
-	meta, err := l.GetCommitMeta(ctx)
+	optCmt, err := load(ctx, ddb, id)
 	if err != nil {
 		return nil, err
 	}
 
-	c := &c{ddb: ddb, commit: l, meta: meta, height: h, hash: id}
+	commit, ok := optCmt.ToCommit()
+	if !ok {
+		return &c{ddb: ddb, commit: optCmt, hash: id}, nil
+	}
+
+	h, err := commit.Height()
+	if err != nil {
+		return nil, err
+	}
+	meta, err := commit.GetCommitMeta(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	c := &c{ddb: ddb, commit: &doltdb.OptionalCommit{Commit: commit, Addr: id}, meta: meta, height: h, hash: id}
 	q.loaded[id] = c
 	return c, nil
 }
@@ -159,13 +182,13 @@ func newQueue() *q {
 //
 // Roughly mimics `git log main..feature` or `git log main...feature` (if
 // more than one `includedHead` is provided).
-func GetDotDotRevisions(ctx context.Context, includedDB *doltdb.DoltDB, includedHeads []hash.Hash, excludedDB *doltdb.DoltDB, excludedHeads []hash.Hash, num int) ([]*doltdb.Commit, error) {
+func GetDotDotRevisions(ctx context.Context, includedDB *doltdb.DoltDB, includedHeads []hash.Hash, excludedDB *doltdb.DoltDB, excludedHeads []hash.Hash, num int) ([]*doltdb.OptionalCommit, error) {
 	itr, err := GetDotDotRevisionsIterator(ctx, includedDB, includedHeads, excludedDB, excludedHeads, nil)
 	if err != nil {
 		return nil, err
 	}
 
-	var commitList []*doltdb.Commit
+	var commitList []*doltdb.OptionalCommit
 	for num < 0 || len(commitList) < num {
 		_, commit, err := itr.Next(ctx)
 		if err == io.EOF {
@@ -180,29 +203,22 @@ func GetDotDotRevisions(ctx context.Context, includedDB *doltdb.DoltDB, included
 	return commitList, nil
 }
 
-// GetTopologicalOrderCommits returns the commits reachable from the commits in `startCommitHashes`
-// in reverse topological order, with tiebreaking done by the height of the commit graph -- higher commits
-// appear first. Remaining ties are broken by timestamp; newer commits appear first.
-func GetTopologicalOrderCommits(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash) ([]*doltdb.Commit, error) {
-	return GetTopNTopoOrderedCommitsMatching(ctx, ddb, startCommitHashes, -1, nil)
-}
-
 // GetTopologicalOrderCommitIterator returns an iterator for commits generated with the same semantics as
 // GetTopologicalOrderCommits
-func GetTopologicalOrderIterator(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, matchFn func(*doltdb.Commit) (bool, error)) (doltdb.CommitItr, error) {
+func GetTopologicalOrderIterator(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, matchFn func(*doltdb.OptionalCommit) (bool, error)) (doltdb.CommitItr, error) {
 	return newCommiterator(ctx, ddb, startCommitHashes, matchFn)
 }
 
 type commiterator struct {
 	ddb               *doltdb.DoltDB
 	startCommitHashes []hash.Hash
-	matchFn           func(*doltdb.Commit) (bool, error)
+	matchFn           func(*doltdb.OptionalCommit) (bool, error)
 	q                 *q
 }
 
 var _ doltdb.CommitItr = (*commiterator)(nil)
 
-func newCommiterator(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, matchFn func(*doltdb.Commit) (bool, error)) (*commiterator, error) {
+func newCommiterator(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, matchFn func(*doltdb.OptionalCommit) (bool, error)) (*commiterator, error) {
 	itr := &commiterator{
 		ddb:               ddb,
 		startCommitHashes: startCommitHashes,
@@ -218,23 +234,29 @@ func newCommiterator(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes
 }
 
 // Next implements doltdb.CommitItr
-func (i *commiterator) Next(ctx context.Context) (hash.Hash, *doltdb.Commit, error) {
-	if i.q.NumVisiblePending() > 0 {
-		nextC := i.q.PopPending()
-		parents, err := nextC.commit.ParentHashes(ctx)
-		if err != nil {
-			return hash.Hash{}, nil, err
+func (iter *commiterator) Next(ctx context.Context) (hash.Hash, *doltdb.OptionalCommit, error) {
+	if iter.q.NumVisiblePending() > 0 {
+		nextC := iter.q.PopPending()
+
+		var err error
+		parents := []hash.Hash{}
+		commit, ok := nextC.commit.ToCommit()
+		if ok {
+			parents, err = commit.ParentHashes(ctx)
+			if err != nil {
+				return hash.Hash{}, nil, err
+			}
 		}
 
 		for _, parentID := range parents {
-			if err := i.q.AddPendingIfUnseen(ctx, nextC.ddb, parentID); err != nil {
+			if err := iter.q.AddPendingIfUnseen(ctx, nextC.ddb, parentID); err != nil {
 				return hash.Hash{}, nil, err
 			}
 		}
 
 		matches := true
-		if i.matchFn != nil {
-			matches, err = i.matchFn(nextC.commit)
+		if iter.matchFn != nil {
+			matches, err = iter.matchFn(nextC.commit)
 
 			if err != nil {
 				return hash.Hash{}, nil, err
@@ -242,10 +264,10 @@ func (i *commiterator) Next(ctx context.Context) (hash.Hash, *doltdb.Commit, err
 		}
 
 		if matches {
-			return nextC.hash, nextC.commit, nil
+			return nextC.hash, &doltdb.OptionalCommit{Commit: commit, Addr: nextC.hash}, nil
 		}
 
-		return i.Next(ctx)
+		return iter.Next(ctx)
 	}
 
 	return hash.Hash{}, nil, io.EOF
@@ -262,10 +284,16 @@ func (i *commiterator) Reset(ctx context.Context) error {
 	return nil
 }
 
+// GetDotDotRevisionsIterator returns an iterator for commits generated with the same semantics as
+// GetDotDotRevisions
+func GetDotDotRevisionsIterator(ctx context.Context, includedDdb *doltdb.DoltDB, startCommitHashes []hash.Hash, excludedDdb *doltdb.DoltDB, excludingCommitHashes []hash.Hash, matchFn func(*doltdb.OptionalCommit) (bool, error)) (doltdb.CommitItr, error) {
+	return newDotDotCommiterator(ctx, includedDdb, startCommitHashes, excludedDdb, excludingCommitHashes, matchFn)
+}
+
 // GetTopNTopoOrderedCommitsMatching returns the first N commits (If N <= 0 then all commits) reachable from the commits in
 // `startCommitHashes` in reverse topological order, with tiebreaking done by the height of the commit graph -- higher
-// commits appear first. Remaining ties are broken by timestamp; newer commits appear first.
-func GetTopNTopoOrderedCommitsMatching(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, n int, matchFn func(*doltdb.Commit) (bool, error)) ([]*doltdb.Commit, error) {
+// commits appear first. Remaining ties are broken by timestamp; newer commits appear first. DO NOT DELETE, USED IN DOLTHUB
+func GetTopNTopoOrderedCommitsMatching(ctx context.Context, ddb *doltdb.DoltDB, startCommitHashes []hash.Hash, n int, matchFn func(commit *doltdb.OptionalCommit) (bool, error)) ([]*doltdb.Commit, error) {
 	itr, err := GetTopologicalOrderIterator(ctx, ddb, startCommitHashes, matchFn)
 	if err != nil {
 		return nil, err
@@ -273,37 +301,33 @@ func GetTopNTopoOrderedCommitsMatching(ctx context.Context, ddb *doltdb.DoltDB,
 
 	var commitList []*doltdb.Commit
 	for n < 0 || len(commitList) < n {
-		_, commit, err := itr.Next(ctx)
+		_, optCmt, err := itr.Next(ctx)
 		if err == io.EOF {
 			break
 		} else if err != nil {
 			return nil, err
 		}
-
+		commit, ok := optCmt.ToCommit()
+		if !ok {
+			return nil, doltdb.ErrGhostCommitEncountered
+		}
 		commitList = append(commitList, commit)
 	}
-
 	return commitList, nil
 }
 
-// GetDotDotRevisionsIterator returns an iterator for commits generated with the same semantics as
-// GetDotDotRevisions
-func GetDotDotRevisionsIterator(ctx context.Context, includedDdb *doltdb.DoltDB, startCommitHashes []hash.Hash, excludedDdb *doltdb.DoltDB, excludingCommitHashes []hash.Hash, matchFn func(*doltdb.Commit) (bool, error)) (doltdb.CommitItr, error) {
-	return newDotDotCommiterator(ctx, includedDdb, startCommitHashes, excludedDdb, excludingCommitHashes, matchFn)
-}
-
 type dotDotCommiterator struct {
 	includedDdb           *doltdb.DoltDB
 	excludedDdb           *doltdb.DoltDB
 	startCommitHashes     []hash.Hash
 	excludingCommitHashes []hash.Hash
-	matchFn               func(*doltdb.Commit) (bool, error)
+	matchFn               func(*doltdb.OptionalCommit) (bool, error)
 	q                     *q
 }
 
 var _ doltdb.CommitItr = (*dotDotCommiterator)(nil)
 
-func newDotDotCommiterator(ctx context.Context, includedDdb *doltdb.DoltDB, startCommitHashes []hash.Hash, excludedDdb *doltdb.DoltDB, excludingCommitHashes []hash.Hash, matchFn func(*doltdb.Commit) (bool, error)) (*dotDotCommiterator, error) {
+func newDotDotCommiterator(ctx context.Context, includedDdb *doltdb.DoltDB, startCommitHashes []hash.Hash, excludedDdb *doltdb.DoltDB, excludingCommitHashes []hash.Hash, matchFn func(*doltdb.OptionalCommit) (bool, error)) (*dotDotCommiterator, error) {
 	itr := &dotDotCommiterator{
 		includedDdb:           includedDdb,
 		excludedDdb:           excludedDdb,
@@ -321,10 +345,16 @@ func newDotDotCommiterator(ctx context.Context, includedDdb *doltdb.DoltDB, star
 }
 
 // Next implements doltdb.CommitItr
-func (i *dotDotCommiterator) Next(ctx context.Context) (hash.Hash, *doltdb.Commit, error) {
+func (i *dotDotCommiterator) Next(ctx context.Context) (hash.Hash, *doltdb.OptionalCommit, error) {
 	if i.q.NumVisiblePending() > 0 {
 		nextC := i.q.PopPending()
-		parents, err := nextC.commit.ParentHashes(ctx)
+
+		commit, ok := nextC.commit.ToCommit()
+		if !ok {
+			return nextC.hash, nextC.commit, nil
+		}
+
+		parents, err := commit.ParentHashes(ctx)
 		if err != nil {
 			return hash.Hash{}, nil, err
 		}
