@@ -68,8 +68,10 @@ func TestGetDotDotRevisions(t *testing.T) {
 
 	cs, err := doltdb.NewCommitSpec(env.DefaultInitBranch)
 	require.NoError(t, err)
-	commit, err := dEnv.DoltDB.Resolve(context.Background(), cs, nil)
+	opt, err := dEnv.DoltDB.Resolve(context.Background(), cs, nil)
 	require.NoError(t, err)
+	commit, ok := opt.ToCommit()
+	require.True(t, ok)
 
 	rv, err := commit.GetRootValue(context.Background())
 	require.NoError(t, err)
@@ -238,8 +240,24 @@ func TestGetDotDotRevisions(t *testing.T) {
 	assertEqualHashes(t, featureCommits[1], res[2])
 }
 
-func assertEqualHashes(t *testing.T, lc, rc *doltdb.Commit) {
-	assert.Equal(t, mustGetHash(t, lc), mustGetHash(t, rc))
+func assertEqualHashes(t *testing.T, lc, rc interface{}) {
+	leftCm, ok := lc.(*doltdb.Commit)
+	if !ok {
+		opt, ok := lc.(*doltdb.OptionalCommit)
+		require.True(t, ok)
+		leftCm, ok = opt.ToCommit()
+		require.True(t, ok)
+	}
+
+	rightCm, ok := rc.(*doltdb.Commit)
+	if !ok {
+		opt, ok := rc.(*doltdb.OptionalCommit)
+		require.True(t, ok)
+		rightCm, ok = opt.ToCommit()
+		require.True(t, ok)
+	}
+
+	assert.Equal(t, mustGetHash(t, leftCm), mustGetHash(t, rightCm))
 }
 
 func mustCreateCommit(t *testing.T, ddb *doltdb.DoltDB, bn string, rvh hash.Hash, parents ...*doltdb.Commit) *doltdb.Commit {
@@ -268,7 +286,7 @@ func mustForkDB(t *testing.T, fromDB *doltdb.DoltDB, bn string, cm *doltdb.Commi
 		for range ps {
 		}
 	}()
-	err = forkEnv.DoltDB.PullChunks(context.Background(), "", fromDB, []hash.Hash{h}, ps)
+	err = forkEnv.DoltDB.PullChunks(context.Background(), "", fromDB, []hash.Hash{h}, ps, nil)
 	if err == pull.ErrDBUpToDate {
 		err = nil
 	}
