@@ -110,7 +110,7 @@ func TestKeylessMerge(t *testing.T) {
 
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
-			root, err = root.CreateEmptyTable(ctx, tblName, keylessSch)
+			root, err = doltdb.CreateEmptyTable(ctx, root, doltdb.TableName{Name: tblName}, keylessSch)
 			require.NoError(t, err)
 			err = dEnv.UpdateWorkingRoot(ctx, root)
 			require.NoError(t, err)
@@ -124,7 +124,7 @@ func TestKeylessMerge(t *testing.T) {
 
 			root, err = dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tblName)
+			tbl, _, err := root.GetTable(ctx, doltdb.TableName{Name: tblName})
 			require.NoError(t, err)
 
 			assertKeylessRows(t, ctx, tbl, test.expected)
@@ -245,7 +245,7 @@ func TestKeylessMergeConflicts(t *testing.T) {
 	setupTest := func(t *testing.T, ctx context.Context, dEnv *env.DoltEnv, cc []testCommand) {
 		root, err := dEnv.WorkingRoot(ctx)
 		require.NoError(t, err)
-		root, err = root.CreateEmptyTable(ctx, tblName, keylessSch)
+		root, err = doltdb.CreateEmptyTable(ctx, root, doltdb.TableName{Name: tblName}, keylessSch)
 		require.NoError(t, err)
 		err = dEnv.UpdateWorkingRoot(ctx, root)
 		require.NoError(t, err)
@@ -270,7 +270,7 @@ func TestKeylessMergeConflicts(t *testing.T) {
 
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tblName)
+			tbl, _, err := root.GetTable(ctx, doltdb.TableName{Name: tblName})
 			require.NoError(t, err)
 			assertConflicts(t, ctx, tbl, test.conflicts)
 		})
@@ -292,7 +292,7 @@ func TestKeylessMergeConflicts(t *testing.T) {
 
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tblName)
+			tbl, _, err := root.GetTable(ctx, doltdb.TableName{Name: tblName})
 			require.NoError(t, err)
 
 			assertKeylessRows(t, ctx, tbl, test.oursExpected)
@@ -312,7 +312,7 @@ func TestKeylessMergeConflicts(t *testing.T) {
 
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
-			tbl, _, err := root.GetTable(ctx, tblName)
+			tbl, _, err := root.GetTable(ctx, doltdb.TableName{Name: tblName})
 			require.NoError(t, err)
 
 			assertKeylessRows(t, ctx, tbl, test.theirsExpected)
@@ -418,7 +418,7 @@ func mustGetRowValueFromTable(t *testing.T, ctx context.Context, tbl *doltdb.Tab
 func mustGetRowValueFromRootIsh(t *testing.T, ctx context.Context, vrw types.ValueReadWriter, ns tree.NodeStore, rootIsh hash.Hash, tblName string, key val.Tuple) val.Tuple {
 	rv, err := doltdb.LoadRootValueFromRootIshAddr(ctx, vrw, ns, rootIsh)
 	require.NoError(t, err)
-	tbl, ok, err := rv.GetTable(ctx, tblName)
+	tbl, ok, err := rv.GetTable(ctx, doltdb.TableName{Name: tblName})
 	require.NoError(t, err)
 	require.True(t, ok)
 
