@@ -158,14 +158,13 @@ func initMigrationDB(ctx context.Context, existing *env.DoltEnv, src, dest files
 	if err != nil {
 		return err
 	}
-	nv := doltdb.HackNomsValuesFromRootValues(rv)
 
 	ds, err := db.GetDataset(ctx, ref.NewInternalRef(migrationRef).String())
 	if err != nil {
 		return err
 	}
 
-	_, err = db.Commit(ctx, ds, nv, datas.CommitOptions{Meta: meta})
+	_, err = db.Commit(ctx, ds, rv.NomsValue(), datas.CommitOptions{Meta: meta})
 	return nil
 }
 
