@@ -224,7 +224,6 @@ func migrateInitCommit(ctx context.Context, cm *doltdb.Commit, new *doltdb.DoltD
 	if err != nil {
 		return err
 	}
-	nv := doltdb.HackNomsValuesFromRootValues(rv)
 
 	meta, err := cm.GetCommitMeta(ctx)
 	if err != nil {
@@ -237,7 +236,7 @@ func migrateInitCommit(ctx context.Context, cm *doltdb.Commit, new *doltdb.DoltD
 	if err != nil {
 		return err
 	}
-	ds, err = datasDB.Commit(ctx, ds, nv, datas.CommitOptions{Meta: meta})
+	ds, err = datasDB.Commit(ctx, ds, rv.NomsValue(), datas.CommitOptions{Meta: meta})
 	if err != nil {
 		return err
 	}
@@ -282,7 +281,7 @@ func migrateCommitOptions(ctx context.Context, oldCm *doltdb.Commit, prog *progr
 	}, nil
 }
 
-func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newParent *doltdb.RootValue) (*doltdb.RootValue, error) {
+func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newParent doltdb.RootValue) (doltdb.RootValue, error) {
 	migrated := newParent
 
 	fkc, err := oldRoot.GetForeignKeyCollection(ctx)
@@ -325,7 +324,7 @@ func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newP
 		// diff against an empty table and rewrite everything
 		var parentSch schema.Schema
 
-		oldParentTbl, ok, err := oldParent.GetTable(ctx, name)
+		oldParentTbl, ok, err := oldParent.GetTable(ctx, doltdb.TableName{Name: name})
 		if err != nil {
 			return true, err
 		}
@@ -343,7 +342,7 @@ func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newP
 			}
 		}
 
-		newParentTbl, ok, err := newParent.GetTable(ctx, name)
+		newParentTbl, ok, err := newParent.GetTable(ctx, doltdb.TableName{Name: name})
 		if err != nil {
 			return true, err
 		}
@@ -360,7 +359,7 @@ func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newP
 			return true, err
 		}
 
-		migrated, err = migrated.PutTable(ctx, name, mtbl)
+		migrated, err = migrated.PutTable(ctx, doltdb.TableName{Name: name}, mtbl)
 		if err != nil {
 			return true, err
 		}
@@ -374,13 +373,13 @@ func migrateRoot(ctx context.Context, menv Environment, oldParent, oldRoot, newP
 }
 
 // renames also get returned here
-func getRemovedTableNames(ctx context.Context, prev, curr *doltdb.RootValue) ([]string, error) {
-	prevNames, err := prev.GetTableNames(ctx)
+func getRemovedTableNames(ctx context.Context, prev, curr doltdb.RootValue) ([]string, error) {
+	prevNames, err := prev.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
 	tblNameSet := set.NewStrSet(prevNames)
-	currNames, err := curr.GetTableNames(ctx)
+	currNames, err := curr.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -566,19 +565,19 @@ func migrateIndexSet(
 		return nil, err
 	}
 	for _, def := range sch.Indexes().AllIndexes() {
-		idx, err := oldParentSet.GetIndex(ctx, sch, def.Name())
+		idx, err := oldParentSet.GetIndex(ctx, sch, nil, def.Name())
 		if err != nil {
 			return nil, err
 		}
 		oldParent := durable.NomsMapFromIndex(idx)
 
-		idx, err = oldSet.GetIndex(ctx, sch, def.Name())
+		idx, err = oldSet.GetIndex(ctx, sch, nil, def.Name())
 		if err != nil {
 			return nil, err
 		}
 		old := durable.NomsMapFromIndex(idx)
 
-		idx, err = newParentSet.GetIndex(ctx, sch, def.Name())
+		idx, err = newParentSet.GetIndex(ctx, sch, nil, def.Name())
 		if err != nil {
 			return nil, err
 		}
