@@ -193,13 +193,18 @@ func findRebaseCommits(ctx *sql.Context, currentBranchCommit, upstreamBranchComm
 	// Drain the iterator into a slice so that we can easily reverse the order of the commits
 	// so that the oldest commit is first in the generated rebase plan.
 	for {
-		_, commit, err := commitItr.Next(ctx)
+		_, optCmt, err := commitItr.Next(ctx)
 		if err == io.EOF {
 			return commits, nil
 		} else if err != nil {
 			return nil, err
 		}
 
+		commit, ok := optCmt.ToCommit()
+		if !ok {
+			return nil, doltdb.ErrGhostCommitEncountered // Not sure if we can get this far. commit walk is going to be a bear.
+		}
+
 		// Don't include merge commits in the rebase plan
 		if commit.NumParents() == 1 {
 			commits = append(commits, commit)
