@@ -178,6 +178,7 @@ func ValidateForInsert(allCols *ColCollection) error {
 			seenPkCol = true
 			break
 		}
+		c.TypeInfo.ToSqlType()
 	}
 
 	if !seenPkCol && !FeatureFlagKeylessSchema {
@@ -198,7 +199,7 @@ func ValidateForInsert(allCols *ColCollection) error {
 		}
 		colNames[col.Name] = true
 
-		if col.AutoIncrement && !isAutoIncrementKind(col.Kind) {
+		if col.AutoIncrement && !(isAutoIncrementKind(col.Kind) || isAutoIncrementType(col.TypeInfo.ToSqlType().Type())) {
 			return true, ErrNonAutoIncType
 		}
 
@@ -208,11 +209,60 @@ func ValidateForInsert(allCols *ColCollection) error {
 	return err
 }
 
+// MaxRowStorageSize returns the storage length for Dolt types.
+func MaxRowStorageSize(sch sql.Schema) int64 {
+	var numBytesPerRow int64 = 0
+	for _, col := range sch {
+		switch n := col.Type.(type) {
+		case sql.NumberType:
+			numBytesPerRow += 8
+		case sql.StringType:
+			if gmstypes.IsTextBlob(n) {
+				numBytesPerRow += 20
+			} else {
+				numBytesPerRow += n.MaxByteLength()
+			}
+		case gmstypes.BitType:
+			numBytesPerRow += 8
+		case sql.DatetimeType:
+			numBytesPerRow += 8
+		case sql.DecimalType:
+			numBytesPerRow += int64(n.MaximumScale())
+		case sql.EnumType:
+			numBytesPerRow += 2
+		case gmstypes.JsonType:
+			numBytesPerRow += 20
+		case sql.NullType:
+			numBytesPerRow += 1
+		case gmstypes.TimeType:
+			numBytesPerRow += 16
+		case sql.YearType:
+			numBytesPerRow += 8
+		default:
+			panic(fmt.Sprintf("unknown type in create table: %s", n.String()))
+		}
+	}
+	return numBytesPerRow
+}
+
 // isAutoIncrementKind returns true is |k| is a numeric kind.
 func isAutoIncrementKind(k types.NomsKind) bool {
 	return k == types.IntKind || k == types.UintKind || k == types.FloatKind
 }
 
+// isAutoIncrementType returns true is |t| is a numeric type.
+// This is an alternative way for the numeric type check.
+func isAutoIncrementType(t query.Type) bool {
+	switch t {
+	case query.Type_INT8, query.Type_INT16, query.Type_INT24, query.Type_INT32, query.Type_INT64,
+		query.Type_UINT8, query.Type_UINT16, query.Type_UINT24, query.Type_UINT32, query.Type_UINT64,
+		query.Type_FLOAT32, query.Type_FLOAT64, query.Type_DECIMAL:
+		return true
+	default:
+		return false
+	}
+}
+
 // UnkeyedSchemaFromCols creates a schema without any primary keys to be used for displaying to users, tests, etc. Such
 // unkeyed schemas are not suitable to be inserted into storage.
 func UnkeyedSchemaFromCols(allCols *ColCollection) Schema {
