@@ -32,11 +32,11 @@ import (
 	"github.com/dolthub/go-mysql-server/sql/planbuilder"
 	"github.com/dolthub/go-mysql-server/sql/rowexec"
 	"github.com/dolthub/go-mysql-server/sql/types"
-	"github.com/dolthub/vitess/go/vt/sqlparser"
 	"github.com/shopspring/decimal"
 	"gopkg.in/src-d/go-errors.v1"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/branch_control"
+	"github.com/dolthub/dolt/go/libraries/doltcore/diff"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env/actions/commitwalk"
@@ -56,12 +56,14 @@ import (
 
 var ErrInvalidTableName = errors.NewKind("Invalid table name %s.")
 var ErrReservedTableName = errors.NewKind("Invalid table name %s. Table names beginning with `dolt_` are reserved for internal use")
+var ErrReservedDiffTableName = errors.NewKind("Invalid table name %s. Table names beginning with `__DATABASE__` are reserved for internal use")
 var ErrSystemTableAlter = errors.NewKind("Cannot alter table %s: system tables cannot be dropped or altered")
 
 // Database implements sql.Database for a dolt DB.
 type Database struct {
 	baseName      string
 	requestedName string
+	schemaName    string
 	ddb           *doltdb.DoltDB
 	rsr           env.RepoStateReader
 	rsw           env.RepoStateWriter
@@ -91,6 +93,8 @@ var _ sql.AliasedDatabase = Database{}
 var _ fulltext.Database = Database{}
 var _ rebase.RebasePlanDatabase = Database{}
 var _ sql.SchemaValidator = Database{}
+var _ sql.SchemaDatabase = Database{}
+var _ sql.DatabaseSchema = Database{}
 
 type ReadOnlyDatabase struct {
 	Database
@@ -193,6 +197,10 @@ func (db Database) Name() string {
 	return db.RequestedName()
 }
 
+func (db Database) Schema() string {
+	return db.schemaName
+}
+
 // AliasedName is what allows databases named e.g. `mydb/b1` to work with the grant and info schema tables that expect
 // a base (no revision qualifier) db name
 func (db Database) AliasedName() string {
@@ -305,7 +313,7 @@ func (db Database) GetTableInsensitiveAsOf(ctx *sql.Context, tableName string, a
 
 }
 
-func (db Database) getTableInsensitive(ctx *sql.Context, head *doltdb.Commit, ds *dsess.DoltSession, root *doltdb.RootValue, tblName string, asOf interface{}) (sql.Table, bool, error) {
+func (db Database) getTableInsensitive(ctx *sql.Context, head *doltdb.Commit, ds *dsess.DoltSession, root doltdb.RootValue, tblName string, asOf interface{}) (sql.Table, bool, error) {
 	lwrName := strings.ToLower(tblName)
 
 	// TODO: these tables that cache a root value at construction time should not, they need to get it from the session
@@ -446,6 +454,7 @@ func (db Database) getTableInsensitive(ctx *sql.Context, head *doltdb.Commit, ds
 		if err != nil {
 			return nil, false, err
 		}
+
 		dt, found = dtables.NewStatusTable(ctx, db.ddb, ws, adapter), true
 	case doltdb.MergeStatusTableName:
 		dt, found = dtables.NewMergeStatusTable(db.RevisionQualifiedName()), true
@@ -510,7 +519,7 @@ func (db Database) getTableInsensitive(ctx *sql.Context, head *doltdb.Commit, ds
 }
 
 // resolveAsOf resolves given expression to a commit, if one exists.
-func resolveAsOf(ctx *sql.Context, db Database, asOf interface{}) (*doltdb.Commit, *doltdb.RootValue, error) {
+func resolveAsOf(ctx *sql.Context, db Database, asOf interface{}) (*doltdb.Commit, doltdb.RootValue, error) {
 	head, err := db.rsr.CWBHeadRef()
 	if err != nil {
 		return nil, nil, err
@@ -525,7 +534,7 @@ func resolveAsOf(ctx *sql.Context, db Database, asOf interface{}) (*doltdb.Commi
 	}
 }
 
-func resolveAsOfTime(ctx *sql.Context, ddb *doltdb.DoltDB, head ref.DoltRef, asOf time.Time) (*doltdb.Commit, *doltdb.RootValue, error) {
+func resolveAsOfTime(ctx *sql.Context, ddb *doltdb.DoltDB, head ref.DoltRef, asOf time.Time) (*doltdb.Commit, doltdb.RootValue, error) {
 	cs, err := doltdb.NewCommitSpec("HEAD")
 	if err != nil {
 		return nil, nil, err
@@ -578,7 +587,7 @@ func resolveAsOfTime(ctx *sql.Context, ddb *doltdb.DoltDB, head ref.DoltRef, asO
 	return nil, nil, nil
 }
 
-func resolveAsOfCommitRef(ctx *sql.Context, db Database, head ref.DoltRef, commitRef string) (*doltdb.Commit, *doltdb.RootValue, error) {
+func resolveAsOfCommitRef(ctx *sql.Context, db Database, head ref.DoltRef, commitRef string) (*doltdb.Commit, doltdb.RootValue, error) {
 	ddb := db.ddb
 
 	if commitRef == doltdb.Working || commitRef == doltdb.Staged {
@@ -632,7 +641,7 @@ func (db Database) GetTableNamesAsOf(ctx *sql.Context, time interface{}) ([]stri
 		return nil, nil
 	}
 
-	tblNames, err := root.GetTableNames(ctx)
+	tblNames, err := root.GetTableNames(ctx, doltdb.DefaultSchemaName)
 	if err != nil {
 		return nil, err
 	}
@@ -640,7 +649,7 @@ func (db Database) GetTableNamesAsOf(ctx *sql.Context, time interface{}) ([]stri
 }
 
 // getTable returns the user table with the given baseName from the root given
-func (db Database) getTable(ctx *sql.Context, root *doltdb.RootValue, tableName string) (sql.Table, bool, error) {
+func (db Database) getTable(ctx *sql.Context, root doltdb.RootValue, tableName string) (sql.Table, bool, error) {
 	sess := dsess.DSessFromSess(ctx.Session)
 	dbState, ok, err := sess.LookupDbState(ctx, db.RevisionQualifiedName())
 	if err != nil {
@@ -662,13 +671,13 @@ func (db Database) getTable(ctx *sql.Context, root *doltdb.RootValue, tableName
 			return nil, false, err
 		}
 
-		cachedTable, ok := dbState.SessionCache().GetCachedTable(key, tableName)
+		cachedTable, ok := dbState.SessionCache().GetCachedTable(key, dsess.TableCacheKey{Name: tableName, Schema: db.schemaName})
 		if ok {
 			return cachedTable, true, nil
 		}
 	}
 
-	tableNames, err := getAllTableNames(ctx, root)
+	tableNames, err := db.getAllTableNames(ctx, root)
 	if err != nil {
 		return nil, true, err
 	}
@@ -678,7 +687,8 @@ func (db Database) getTable(ctx *sql.Context, root *doltdb.RootValue, tableName
 		return nil, false, nil
 	}
 
-	tbl, ok, err := root.GetTable(ctx, tableName)
+	// TODO: should we short-circuit the schema name for system tables?
+	tbl, ok, err := root.GetTable(ctx, doltdb.TableName{Name: tableName, Schema: db.schemaName})
 	if err != nil {
 		return nil, false, err
 	} else if !ok {
@@ -709,7 +719,7 @@ func (db Database) getTable(ctx *sql.Context, root *doltdb.RootValue, tableName
 		if err != nil {
 			return nil, false, err
 		}
-		dbState.SessionCache().CacheTable(key, tableName, table)
+		dbState.SessionCache().CacheTable(key, dsess.TableCacheKey{Name: tableName, Schema: db.schemaName}, table)
 	}
 
 	return table, true, nil
@@ -762,15 +772,15 @@ func (db Database) GetAllTableNames(ctx *sql.Context) ([]string, error) {
 		return nil, err
 	}
 
-	return getAllTableNames(ctx, root)
+	return db.getAllTableNames(ctx, root)
 }
 
-func getAllTableNames(ctx context.Context, root *doltdb.RootValue) ([]string, error) {
+func (db Database) getAllTableNames(ctx context.Context, root doltdb.RootValue) ([]string, error) {
 	systemTables, err := doltdb.GetGeneratedSystemTables(ctx, root)
 	if err != nil {
 		return nil, err
 	}
-	result, err := root.GetTableNames(ctx)
+	result, err := root.GetTableNames(ctx, db.schemaName)
 	result = append(result, systemTables...)
 	return result, err
 }
@@ -786,7 +796,7 @@ func filterDoltInternalTables(tblNames []string) []string {
 }
 
 // GetRoot returns the root value for this database session
-func (db Database) GetRoot(ctx *sql.Context) (*doltdb.RootValue, error) {
+func (db Database) GetRoot(ctx *sql.Context) (doltdb.RootValue, error) {
 	sess := dsess.DSessFromSess(ctx.Session)
 	dbState, ok, err := sess.LookupDbState(ctx, db.RevisionQualifiedName())
 	if err != nil {
@@ -822,13 +832,13 @@ func (db Database) GetWorkingSet(ctx *sql.Context) (*doltdb.WorkingSet, error) {
 
 // SetRoot should typically be called on the Session, which is where this state lives. But it's available here as a
 // convenience.
-func (db Database) SetRoot(ctx *sql.Context, newRoot *doltdb.RootValue) error {
+func (db Database) SetRoot(ctx *sql.Context, newRoot doltdb.RootValue) error {
 	sess := dsess.DSessFromSess(ctx.Session)
-	return sess.SetRoot(ctx, db.RevisionQualifiedName(), newRoot)
+	return sess.SetWorkingRoot(ctx, db.RevisionQualifiedName(), newRoot)
 }
 
 // GetHeadRoot returns root value for the current session head
-func (db Database) GetHeadRoot(ctx *sql.Context) (*doltdb.RootValue, error) {
+func (db Database) GetHeadRoot(ctx *sql.Context) (doltdb.RootValue, error) {
 	sess := dsess.DSessFromSess(ctx.Session)
 	head, err := sess.GetHeadCommit(ctx, db.RevisionQualifiedName())
 	if err != nil {
@@ -864,7 +874,7 @@ func (db Database) dropTable(ctx *sql.Context, tableName string) error {
 	}
 
 	root := ws.WorkingRoot()
-	tbl, tableExists, err := root.GetTable(ctx, tableName)
+	tbl, tableExists, err := root.GetTable(ctx, doltdb.TableName{Name: tableName})
 	if err != nil {
 		return err
 	}
@@ -950,15 +960,20 @@ func (db Database) CreateTable(ctx *sql.Context, tableName string, sch sql.Prima
 	if err := dsess.CheckAccessForDb(ctx, db, branch_control.Permissions_Write); err != nil {
 		return err
 	}
+
 	if doltdb.HasDoltPrefix(tableName) && !doltdb.IsFullTextTable(tableName) {
 		return ErrReservedTableName.New(tableName)
 	}
 
+	if strings.HasPrefix(tableName, diff.DBPrefix) {
+		return ErrReservedDiffTableName.New(tableName)
+	}
+
 	if !doltdb.IsValidTableName(tableName) {
 		return ErrInvalidTableName.New(tableName)
 	}
 
-	return db.createSqlTable(ctx, tableName, sch, collation, comment)
+	return db.createSqlTable(ctx, tableName, db.schemaName, sch, collation, comment)
 }
 
 // CreateIndexedTable creates a table with the name and schema given.
@@ -966,15 +981,20 @@ func (db Database) CreateIndexedTable(ctx *sql.Context, tableName string, sch sq
 	if err := dsess.CheckAccessForDb(ctx, db, branch_control.Permissions_Write); err != nil {
 		return err
 	}
+
 	if doltdb.HasDoltPrefix(tableName) {
 		return ErrReservedTableName.New(tableName)
 	}
 
+	if strings.HasPrefix(tableName, diff.DBPrefix) {
+		return ErrReservedDiffTableName.New(tableName)
+	}
+
 	if !doltdb.IsValidTableName(tableName) {
 		return ErrInvalidTableName.New(tableName)
 	}
 
-	return db.createIndexedSqlTable(ctx, tableName, sch, idxDef, collation)
+	return db.createIndexedSqlTable(ctx, tableName, db.schemaName, sch, idxDef, collation)
 }
 
 // CreateFulltextTableNames returns a set of names that will be used to create Full-Text pseudo-index tables.
@@ -1004,13 +1024,15 @@ OuterLoop:
 }
 
 // createSqlTable is the private version of CreateTable. It doesn't enforce any table name checks.
-func (db Database) createSqlTable(ctx *sql.Context, tableName string, sch sql.PrimaryKeySchema, collation sql.CollationID, comment string) error {
+func (db Database) createSqlTable(ctx *sql.Context, tableName string, schemaName string, sch sql.PrimaryKeySchema, collation sql.CollationID, comment string) error {
 	ws, err := db.GetWorkingSet(ctx)
 	if err != nil {
 		return err
 	}
 	root := ws.WorkingRoot()
 
+	// TODO: enforce that schema exists (redundant with other checks)
+
 	if exists, err := root.HasTable(ctx, tableName); err != nil {
 		return err
 	} else if exists {
@@ -1043,11 +1065,26 @@ func (db Database) createSqlTable(ctx *sql.Context, tableName string, sch sql.Pr
 		ait.AddNewTable(tableName)
 	}
 
-	return db.createDoltTable(ctx, tableName, root, doltSch)
+	return db.createDoltTable(ctx, tableName, schemaName, root, doltSch)
+}
+
+func hasDatabaseSchema(ctx context.Context, root doltdb.RootValue, schemaName string) (bool, error) {
+	schemas, err := root.GetDatabaseSchemas(ctx)
+	if err != nil {
+		return false, err
+	}
+
+	for _, schema := range schemas {
+		if strings.EqualFold(schema.Name, schemaName) {
+			return true, nil
+		}
+	}
+
+	return false, nil
 }
 
 // createIndexedSqlTable is the private version of createSqlTable. It doesn't enforce any table name checks.
-func (db Database) createIndexedSqlTable(ctx *sql.Context, tableName string, sch sql.PrimaryKeySchema, idxDef sql.IndexDef, collation sql.CollationID) error {
+func (db Database) createIndexedSqlTable(ctx *sql.Context, tableName string, schemaName string, sch sql.PrimaryKeySchema, idxDef sql.IndexDef, collation sql.CollationID) error {
 	ws, err := db.GetWorkingSet(ctx)
 	if err != nil {
 		return err
@@ -1091,11 +1128,11 @@ func (db Database) createIndexedSqlTable(ctx *sql.Context, tableName string, sch
 		ait.AddNewTable(tableName)
 	}
 
-	return db.createDoltTable(ctx, tableName, root, doltSch)
+	return db.createDoltTable(ctx, tableName, schemaName, root, doltSch)
 }
 
 // createDoltTable creates a table on the database using the given dolt schema while not enforcing table baseName checks.
-func (db Database) createDoltTable(ctx *sql.Context, tableName string, root *doltdb.RootValue, doltSch schema.Schema) error {
+func (db Database) createDoltTable(ctx *sql.Context, tableName string, schemaName string, root doltdb.RootValue, doltSch schema.Schema) error {
 	if exists, err := root.HasTable(ctx, tableName); err != nil {
 		return err
 	} else if exists {
@@ -1104,7 +1141,7 @@ func (db Database) createDoltTable(ctx *sql.Context, tableName string, root *dol
 
 	var conflictingTbls []string
 	_ = doltSch.GetAllCols().Iter(func(tag uint64, col schema.Column) (stop bool, err error) {
-		_, oldTableName, exists, err := root.GetTableByColTag(ctx, tag)
+		_, oldTableName, exists, err := doltdb.GetTableByColTag(ctx, root, tag)
 		if err != nil {
 			return true, err
 		}
@@ -1119,7 +1156,7 @@ func (db Database) createDoltTable(ctx *sql.Context, tableName string, root *dol
 		return fmt.Errorf(strings.Join(conflictingTbls, "\n"))
 	}
 
-	newRoot, err := root.CreateEmptyTable(ctx, tableName, doltSch)
+	newRoot, err := doltdb.CreateEmptyTable(ctx, root, doltdb.TableName{Name: tableName, Schema: schemaName}, doltSch)
 	if err != nil {
 		return err
 	}
@@ -1133,6 +1170,10 @@ func (db Database) CreateTemporaryTable(ctx *sql.Context, tableName string, pkSc
 		return ErrReservedTableName.New(tableName)
 	}
 
+	if strings.HasPrefix(tableName, diff.DBPrefix) {
+		return ErrReservedDiffTableName.New(tableName)
+	}
+
 	if !doltdb.IsValidTableName(tableName) {
 		return ErrInvalidTableName.New(tableName)
 	}
@@ -1147,6 +1188,62 @@ func (db Database) CreateTemporaryTable(ctx *sql.Context, tableName string, pkSc
 	return nil
 }
 
+// CreateSchema implements sql.SchemaDatabase
+func (db Database) CreateSchema(ctx *sql.Context, schemaName string) error {
+	if err := dsess.CheckAccessForDb(ctx, db, branch_control.Permissions_Write); err != nil {
+		return err
+	}
+	root, err := db.GetRoot(ctx)
+	if err != nil {
+		return err
+	}
+
+	root, err = root.CreateDatabaseSchema(ctx, schema.DatabaseSchema{
+		Name: schemaName,
+	})
+	if err != nil {
+		return err
+	}
+
+	return db.SetRoot(ctx, root)
+}
+
+// GetSchema implements sql.SchemaDatabase
+func (db Database) GetSchema(ctx *sql.Context, schemaName string) (sql.DatabaseSchema, bool, error) {
+	ws, err := db.GetWorkingSet(ctx)
+	if err != nil {
+		return nil, false, err
+	}
+	root := ws.WorkingRoot()
+
+	schemas, err := root.GetDatabaseSchemas(ctx)
+	if err != nil {
+		return nil, false, err
+	}
+
+	for _, schema := range schemas {
+		if strings.EqualFold(schema.Name, schemaName) {
+			db.schemaName = schema.Name
+			return db, true, nil
+		}
+	}
+
+	// For a temporary backwards compatibility solution, always pretend the public schema exists.
+	// Should create it explicitly when we create a new db in future.
+	if strings.EqualFold(schemaName, "public") {
+		db.schemaName = "public"
+		return db, true, nil
+	}
+
+	return nil, false, nil
+}
+
+// AllSchemas implements sql.SchemaDatabase
+func (db Database) AllSchemas(ctx *sql.Context) ([]sql.DatabaseSchema, error) {
+	db.schemaName = "public"
+	return []sql.DatabaseSchema{db}, nil
+}
+
 // RenameTable implements sql.TableRenamer
 func (db Database) RenameTable(ctx *sql.Context, oldName, newName string) error {
 	if err := dsess.CheckAccessForDb(ctx, db, branch_control.Permissions_Write); err != nil {
@@ -1166,6 +1263,10 @@ func (db Database) RenameTable(ctx *sql.Context, oldName, newName string) error
 		return ErrReservedTableName.New(newName)
 	}
 
+	if strings.HasPrefix(newName, diff.DBPrefix) {
+		return ErrReservedDiffTableName.New(newName)
+	}
+
 	if !doltdb.IsValidTableName(newName) {
 		return ErrInvalidTableName.New(newName)
 	}
@@ -1214,16 +1315,17 @@ func (db Database) GetViewDefinition(ctx *sql.Context, viewName string) (sql.Vie
 	}
 
 	if dbState.SessionCache().ViewsCached(key) {
-		view, ok := dbState.SessionCache().GetCachedViewDefinition(key, viewName)
+		view, ok := dbState.SessionCache().GetCachedViewDefinition(key, dsess.TableCacheKey{Name: viewName, Schema: db.schemaName})
 		return view, ok, nil
 	}
 
+	// TODO: do we need a dolt schemas table in every schema?
 	tbl, ok, err := db.GetTableInsensitive(ctx, doltdb.SchemasTableName)
 	if err != nil {
 		return sql.ViewDefinition{}, false, err
 	}
 	if !ok {
-		dbState.SessionCache().CacheViews(key, nil)
+		dbState.SessionCache().CacheViews(key, nil, db.schemaName)
 		return sql.ViewDefinition{}, false, nil
 	}
 
@@ -1232,7 +1334,8 @@ func (db Database) GetViewDefinition(ctx *sql.Context, viewName string) (sql.Vie
 		return sql.ViewDefinition{}, false, err
 	}
 
-	dbState.SessionCache().CacheViews(key, views)
+	// TODO: only cache views from a single schema here
+	dbState.SessionCache().CacheViews(key, views, db.schemaName)
 
 	return viewDef, found, nil
 }
@@ -1247,19 +1350,20 @@ func getViewDefinitionFromSchemaFragmentsOfView(ctx *sql.Context, tbl *WritableD
 	var viewDef sql.ViewDefinition
 	var views = make([]sql.ViewDefinition, len(fragments))
 	for i, fragment := range fragments {
-		cv, err := sqlparser.ParseWithOptions(fragments[i].fragment,
-			sql.NewSqlModeFromString(fragment.sqlMode).ParserOptions())
-		if err != nil {
-			return nil, sql.ViewDefinition{}, false, err
-		}
-
-		createView, ok := cv.(*sqlparser.DDL)
-		if ok {
-			selectStr := fragments[i].fragment[createView.SubStatementPositionStart:createView.SubStatementPositionEnd]
-			views[i] = sql.ViewDefinition{Name: fragments[i].name, TextDefinition: selectStr,
-				CreateViewStatement: fragments[i].fragment, SqlMode: fragment.sqlMode}
+		if strings.HasPrefix(strings.ToLower(fragments[i].fragment), "select") {
+			// older versions
+			views[i] = sql.ViewDefinition{
+				Name:                fragments[i].name,
+				TextDefinition:      fragments[i].fragment,
+				CreateViewStatement: fmt.Sprintf("CREATE VIEW %s AS %s", fragments[i].name, fragments[i].fragment),
+			}
 		} else {
-			views[i] = sql.ViewDefinition{Name: fragments[i].name, TextDefinition: fragments[i].fragment, CreateViewStatement: fmt.Sprintf("CREATE VIEW %s AS %s", fragments[i].name, fragments[i].fragment)}
+			views[i] = sql.ViewDefinition{
+				Name: fragments[i].name,
+				// TODO: need to define TextDefinition
+				CreateViewStatement: fragments[i].fragment,
+				SqlMode:             fragment.sqlMode,
+			}
 		}
 
 		if strings.ToLower(fragment.name) == strings.ToLower(viewName) {
@@ -1307,6 +1411,32 @@ func (db Database) DropView(ctx *sql.Context, name string) error {
 
 // GetTriggers implements sql.TriggerDatabase.
 func (db Database) GetTriggers(ctx *sql.Context) ([]sql.TriggerDefinition, error) {
+	root, err := db.GetRoot(ctx)
+	if err != nil {
+		return nil, nil
+	}
+
+	key, err := doltdb.NewDataCacheKey(root)
+	if err != nil {
+		return nil, err
+	}
+
+	ds := dsess.DSessFromSess(ctx.Session)
+	dbState, _, err := ds.LookupDbState(ctx, db.RevisionQualifiedName())
+	if err != nil {
+		return nil, nil
+	}
+
+	var triggers []sql.TriggerDefinition
+	var ok bool
+	if triggers, ok = dbState.SessionCache().GetCachedTriggers(key, db.schemaName); ok {
+		return triggers, nil
+	}
+
+	defer func() {
+		dbState.SessionCache().CacheTriggers(key, triggers, db.schemaName)
+	}()
+
 	tbl, ok, err := db.GetTableInsensitive(ctx, doltdb.SchemasTableName)
 	if err != nil {
 		return nil, err
@@ -1320,7 +1450,6 @@ func (db Database) GetTriggers(ctx *sql.Context) ([]sql.TriggerDefinition, error
 		return nil, err
 	}
 
-	var triggers []sql.TriggerDefinition
 	for _, frag := range frags {
 		triggers = append(triggers, sql.TriggerDefinition{
 			Name:            frag.name,
@@ -1450,9 +1579,9 @@ func (db Database) doltSchemaTableHash(ctx *sql.Context) (hash.Hash, error) {
 
 // createEventDefinitionFromFragment creates an EventDefinition instance from the schema fragment |frag|.
 func (db Database) createEventDefinitionFromFragment(ctx *sql.Context, frag schemaFragment) (*sql.EventDefinition, error) {
-	catalog := db.getCatalog(ctx)
-	sqlMode := sql.NewSqlModeFromString(frag.sqlMode)
-	parsed, err := planbuilder.ParseWithOptions(ctx, catalog, updateEventStatusTemporarilyForNonDefaultBranch(db.revision, frag.fragment), sqlMode.ParserOptions())
+	b := planbuilder.New(ctx, db.getCatalog(ctx), sql.NewMysqlParser())
+	b.SetParserOptions(sql.NewSqlModeFromString(frag.sqlMode).ParserOptions())
+	parsed, _, _, err := b.Parse(updateEventStatusTemporarilyForNonDefaultBranch(db.revision, frag.fragment), false)
 	if err != nil {
 		return nil, err
 	}
@@ -1770,7 +1899,7 @@ func (db Database) LoadRebasePlan(ctx *sql.Context) (*rebase.RebasePlan, error)
 func (db Database) SaveRebasePlan(ctx *sql.Context, plan *rebase.RebasePlan) error {
 	pkSchema := sql.NewPrimaryKeySchema(dprocedures.DoltRebaseSystemTableSchema)
 	// we use createSqlTable, instead of CreateTable to avoid the "dolt_" reserved prefix table name check
-	err := db.createSqlTable(ctx, doltdb.RebaseTableName, pkSchema, sql.Collation_Default, "")
+	err := db.createSqlTable(ctx, doltdb.RebaseTableName, "", pkSchema, sql.Collation_Default, "")
 	if err != nil {
 		return err
 	}
@@ -1811,11 +1940,11 @@ func (db Database) SaveRebasePlan(ctx *sql.Context, plan *rebase.RebasePlan) err
 // noopRepoStateWriter is a minimal implementation of RepoStateWriter that does nothing
 type noopRepoStateWriter struct{}
 
-func (n noopRepoStateWriter) UpdateStagedRoot(ctx context.Context, newRoot *doltdb.RootValue) error {
+func (n noopRepoStateWriter) UpdateStagedRoot(ctx context.Context, newRoot doltdb.RootValue) error {
 	return nil
 }
 
-func (n noopRepoStateWriter) UpdateWorkingRoot(ctx context.Context, newRoot *doltdb.RootValue) error {
+func (n noopRepoStateWriter) UpdateWorkingRoot(ctx context.Context, newRoot doltdb.RootValue) error {
 	return nil
 }
 
