@@ -193,10 +193,14 @@ func startRebase(ctx *sql.Context, upstreamPoint string) error {
 		return err
 	}
 
-	upstreamCommit, err := dbData.Ddb.Resolve(ctx, commitSpec, headRef)
+	optCmt, err := dbData.Ddb.Resolve(ctx, commitSpec, headRef)
 	if err != nil {
 		return err
 	}
+	upstreamCommit, ok := optCmt.ToCommit()
+	if !ok {
+		return doltdb.ErrGhostCommitEncountered
+	}
 
 	// rebaseWorkingBranch is the name of the temporary branch used when performing a rebase. In Git, a rebase
 	// happens with a detatched HEAD, but Dolt doesn't support that, we use a temporary branch.
@@ -554,10 +558,16 @@ func squashCommitMessage(ctx *sql.Context, nextCommitHash string) (string, error
 	if err != nil {
 		return "", err
 	}
-	nextCommit, err := ddb.Resolve(ctx, spec, headRef)
+
+	optCmt, err := ddb.Resolve(ctx, spec, headRef)
 	if err != nil {
 		return "", err
 	}
+	nextCommit, ok := optCmt.ToCommit()
+	if !ok {
+		return "", doltdb.ErrGhostCommitEncountered
+	}
+
 	nextCommitMeta, err := nextCommit.GetCommitMeta(ctx)
 	if err != nil {
 		return "", err
