@@ -62,19 +62,15 @@ func doDoltReset(ctx *sql.Context, args []string) (int, error) {
 		return 1, fmt.Errorf("error: --%s and --%s are mutually exclusive options.", cli.HardResetParam, cli.SoftResetParam)
 	}
 
-	provider := dSess.Provider()
-	db, err := provider.Database(ctx, dbName)
-	if err != nil {
-		return 1, err
-	}
-
 	// Disallow manipulating any roots for read-only databases – changing the branch
 	// HEAD would allow changing data, and working set and index shouldn't ever have
 	// any contents for a read-only database.
-	if rodb, ok := db.(sql.ReadOnlyDatabase); ok {
-		if rodb.IsReadOnly() {
-			return 1, fmt.Errorf("unable to reset HEAD in read-only databases")
-		}
+	isReadOnly, err := isReadOnlyDatabase(ctx, dbName)
+	if err != nil {
+		return 1, err
+	}
+	if isReadOnly {
+		return 1, fmt.Errorf("unable to reset HEAD in read-only databases")
 	}
 
 	// Get all the needed roots.
@@ -109,14 +105,16 @@ func doDoltReset(ctx *sql.Context, args []string) (int, error) {
 			}
 		}
 
+		// TODO - refactor and make transactional with the head update above.
 		ws, err := dSess.WorkingSet(ctx, dbName)
 		if err != nil {
 			return 1, err
 		}
-		err = dSess.SetWorkingSet(ctx, dbName, ws.WithWorkingRoot(roots.Working).WithStagedRoot(roots.Staged).ClearMerge())
+		err = dSess.SetWorkingSet(ctx, dbName, ws.WithWorkingRoot(roots.Working).WithStagedRoot(roots.Staged).ClearMerge().ClearRebase())
 		if err != nil {
 			return 1, err
 		}
+
 	} else if apr.Contains(cli.SoftResetParam) {
 		arg := ""
 		if apr.NArg() > 1 {
@@ -134,7 +132,7 @@ func doDoltReset(ctx *sql.Context, args []string) (int, error) {
 			if err != nil {
 				return 1, err
 			}
-			err = dSess.SetWorkingSet(ctx, dbName, ws.WithStagedRoot(roots.Staged).ClearMerge())
+			err = dSess.SetWorkingSet(ctx, dbName, ws.WithStagedRoot(roots.Staged).ClearMerge().ClearRebase())
 			if err != nil {
 				return 1, err
 			}
@@ -172,7 +170,7 @@ func doDoltReset(ctx *sql.Context, args []string) (int, error) {
 				if err != nil {
 					return 1, err
 				}
-				err = dSess.SetWorkingSet(ctx, dbName, ws.WithStagedRoot(roots.Staged).ClearMerge())
+				err = dSess.SetWorkingSet(ctx, dbName, ws.WithStagedRoot(roots.Staged).ClearMerge().ClearRebase())
 				if err != nil {
 					return 1, err
 				}
