@@ -25,9 +25,17 @@ import (
 
 // SessionCache caches various pieces of expensive to compute information to speed up future lookups in the session.
 type SessionCache struct {
+	// indexes is keyed by table schema hash
 	indexes map[doltdb.DataCacheKey]map[string][]sql.Index
-	tables  map[doltdb.DataCacheKey]map[string]sql.Table
-	views   map[doltdb.DataCacheKey]map[string]sql.ViewDefinition
+	// tables is keyed by table root value
+	tables map[doltdb.DataCacheKey]map[TableCacheKey]sql.Table
+
+	// TODO: cache views/triggers by schema fragment hash
+	views    map[doltdb.DataCacheKey]map[TableCacheKey]sql.ViewDefinition
+	triggers map[TableSchemaKey][]sql.TriggerDefinition
+
+	// writers is keyed by table schema hash
+	writers map[doltdb.DataCacheKey]*WriterState
 
 	mu sync.RWMutex
 }
@@ -114,13 +122,12 @@ func (c *SessionCache) GetTableIndexesCache(key doltdb.DataCacheKey, table strin
 }
 
 // CacheTable caches a sql.Table implementation for the table named
-func (c *SessionCache) CacheTable(key doltdb.DataCacheKey, tableName string, table sql.Table) {
+func (c *SessionCache) CacheTable(key doltdb.DataCacheKey, tableName TableCacheKey, table sql.Table) {
 	c.mu.Lock()
 	defer c.mu.Unlock()
 
-	tableName = strings.ToLower(tableName)
 	if c.tables == nil {
-		c.tables = make(map[doltdb.DataCacheKey]map[string]sql.Table)
+		c.tables = make(map[doltdb.DataCacheKey]map[TableCacheKey]sql.Table)
 	}
 	if len(c.tables) > maxCachedKeys {
 		for k := range c.tables {
@@ -130,11 +137,11 @@ func (c *SessionCache) CacheTable(key doltdb.DataCacheKey, tableName string, tab
 
 	tablesForKey, ok := c.tables[key]
 	if !ok {
-		tablesForKey = make(map[string]sql.Table)
+		tablesForKey = make(map[TableCacheKey]sql.Table)
 		c.tables[key] = tablesForKey
 	}
 
-	tablesForKey[tableName] = table
+	tablesForKey[tableName.ToLower()] = table
 }
 
 // ClearTableCache removes all cache info for all tables at all cache keys
@@ -147,12 +154,23 @@ func (c *SessionCache) ClearTableCache() {
 	}
 }
 
+type TableCacheKey struct {
+	Name   string
+	Schema string
+}
+
+func (k TableCacheKey) ToLower() TableCacheKey {
+	return TableCacheKey{
+		Name:   strings.ToLower(k.Name),
+		Schema: strings.ToLower(k.Schema),
+	}
+}
+
 // GetCachedTable returns the cached sql.Table for the table named, and whether the cache was present
-func (c *SessionCache) GetCachedTable(key doltdb.DataCacheKey, tableName string) (sql.Table, bool) {
+func (c *SessionCache) GetCachedTable(key doltdb.DataCacheKey, tableName TableCacheKey) (sql.Table, bool) {
 	c.mu.RLock()
 	defer c.mu.RUnlock()
 
-	tableName = strings.ToLower(tableName)
 	if c.tables == nil {
 		return nil, false
 	}
@@ -162,17 +180,42 @@ func (c *SessionCache) GetCachedTable(key doltdb.DataCacheKey, tableName string)
 		return nil, false
 	}
 
-	table, ok := tablesForKey[tableName]
+	table, ok := tablesForKey[tableName.ToLower()]
 	return table, ok
 }
 
+// GetCachedWriterState returns the cached WriterState for the table named, and whether the cache was present
+func (c *SessionCache) GetCachedWriterState(key doltdb.DataCacheKey) (*WriterState, bool) {
+	c.mu.RLock()
+	defer c.mu.RUnlock()
+	schemaState, ok := c.writers[key]
+	return schemaState, ok
+}
+
+// CacheWriterState caches a WriterState implementation for the table named
+func (c *SessionCache) CacheWriterState(key doltdb.DataCacheKey, state *WriterState) {
+	c.mu.Lock()
+	defer c.mu.Unlock()
+
+	if c.writers == nil {
+		c.writers = make(map[doltdb.DataCacheKey]*WriterState)
+	}
+	if len(c.writers) > maxCachedKeys {
+		for k := range c.writers {
+			delete(c.writers, k)
+		}
+	}
+
+	c.writers[key] = state
+}
+
 // CacheViews caches all views in a database for the cache key given
-func (c *SessionCache) CacheViews(key doltdb.DataCacheKey, views []sql.ViewDefinition) {
+func (c *SessionCache) CacheViews(key doltdb.DataCacheKey, views []sql.ViewDefinition, schema string) {
 	c.mu.Lock()
 	defer c.mu.Unlock()
 
 	if c.views == nil {
-		c.views = make(map[doltdb.DataCacheKey]map[string]sql.ViewDefinition)
+		c.views = make(map[doltdb.DataCacheKey]map[TableCacheKey]sql.ViewDefinition)
 	}
 	if len(c.views) > maxCachedKeys {
 		for k := range c.views {
@@ -182,12 +225,15 @@ func (c *SessionCache) CacheViews(key doltdb.DataCacheKey, views []sql.ViewDefin
 
 	viewsForKey, ok := c.views[key]
 	if !ok {
-		viewsForKey = make(map[string]sql.ViewDefinition)
+		viewsForKey = make(map[TableCacheKey]sql.ViewDefinition)
 		c.views[key] = viewsForKey
 	}
 
 	for i := range views {
-		viewName := strings.ToLower(views[i].Name)
+		viewName := TableCacheKey{
+			Name:   strings.ToLower(views[i].Name),
+			Schema: strings.ToLower(schema),
+		}
 		viewsForKey[viewName] = views[i]
 	}
 }
@@ -206,11 +252,10 @@ func (c *SessionCache) ViewsCached(key doltdb.DataCacheKey) bool {
 }
 
 // GetCachedViewDefinition returns the cached view named, and whether the cache was present
-func (c *SessionCache) GetCachedViewDefinition(key doltdb.DataCacheKey, viewName string) (sql.ViewDefinition, bool) {
+func (c *SessionCache) GetCachedViewDefinition(key doltdb.DataCacheKey, viewName TableCacheKey) (sql.ViewDefinition, bool) {
 	c.mu.RLock()
 	defer c.mu.RUnlock()
 
-	viewName = strings.ToLower(viewName)
 	if c.views == nil {
 		return sql.ViewDefinition{}, false
 	}
@@ -220,10 +265,50 @@ func (c *SessionCache) GetCachedViewDefinition(key doltdb.DataCacheKey, viewName
 		return sql.ViewDefinition{}, false
 	}
 
-	table, ok := viewsForKey[viewName]
+	table, ok := viewsForKey[viewName.ToLower()]
 	return table, ok
 }
 
+type TableSchemaKey struct {
+	key    doltdb.DataCacheKey
+	schema string
+}
+
+// CacheTriggers caches all views in a database for the cache key given
+func (c *SessionCache) CacheTriggers(key doltdb.DataCacheKey, triggers []sql.TriggerDefinition, schema string) {
+	c.mu.Lock()
+	defer c.mu.Unlock()
+
+	if c.triggers == nil {
+		c.triggers = make(map[TableSchemaKey][]sql.TriggerDefinition)
+	}
+	if len(c.triggers) > maxCachedKeys {
+		for k := range c.triggers {
+			delete(c.triggers, k)
+		}
+	}
+
+	schKey := TableSchemaKey{key: key, schema: schema}
+	_, ok := c.triggers[schKey]
+	if !ok {
+		// create backing array to differentiate no triggers/no cache
+		c.triggers[schKey] = make([]sql.TriggerDefinition, 0)
+	}
+
+	c.triggers[schKey] = append(c.triggers[schKey], triggers...)
+}
+
+// GetCachedTriggers returns the cached view named, and whether the cache was present
+func (c *SessionCache) GetCachedTriggers(key doltdb.DataCacheKey, schema string) ([]sql.TriggerDefinition, bool) {
+	c.mu.RLock()
+	defer c.mu.RUnlock()
+
+	schKey := TableSchemaKey{key: key, schema: schema}
+
+	triggers, ok := c.triggers[schKey]
+	return triggers, ok
+}
+
 // GetCachedRevisionDb returns the cached revision database named, and whether the cache was present
 func (c *DatabaseCache) GetCachedRevisionDb(revisionDbName string, requestedName string) (SqlDatabase, bool) {
 	c.mu.RLock()
