@@ -603,7 +603,8 @@ func TestIndexedAccess(t *testing.T, e enginetest.QueryEngine, harness enginetes
 }
 
 func analyzeQuery(ctx *sql.Context, e enginetest.QueryEngine, query string) (sql.Node, error) {
-	parsed, err := planbuilder.Parse(ctx, e.EngineAnalyzer().Catalog, query)
+	binder := planbuilder.New(ctx, e.EngineAnalyzer().Catalog, sql.NewMysqlParser())
+	parsed, _, _, err := binder.Parse(query, false)
 	if err != nil {
 		return nil, err
 	}
