@@ -174,8 +174,10 @@ func TestDoltTransactionCommitOneClient(t *testing.T) {
 	require.NoError(t, err)
 	headRefs, err := db.GetHeadRefs(context.Background())
 	require.NoError(t, err)
-	commit, err := db.Resolve(context.Background(), cs, headRefs[0])
+	optCmt, err := db.Resolve(context.Background(), cs, headRefs[0])
 	require.NoError(t, err)
+	commit, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	cm, err := commit.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, cm.Description, "Commit Message 42")
@@ -184,16 +186,20 @@ func TestDoltTransactionCommitOneClient(t *testing.T) {
 	require.NoError(t, err)
 	headRefs, err = db.GetHeadRefs(context.Background())
 	require.NoError(t, err)
-	commit, err = db.Resolve(context.Background(), cs, headRefs[0])
+	optCmt, err = db.Resolve(context.Background(), cs, headRefs[0])
 	require.NoError(t, err)
+	commit, ok = optCmt.ToCommit()
+	require.True(t, ok)
 	cm, err = commit.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, cm.Description, "Transaction commit")
 
 	as, err := doltdb.NewAncestorSpec("~1")
 	require.NoError(t, err)
-	initialCommit, err := commit.GetAncestor(context.Background(), as)
+	optCmt, err = commit.GetAncestor(context.Background(), as)
 	require.NoError(t, err)
+	initialCommit, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	icm, err := initialCommit.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Equal(t, "checkpoint enginetest database mydb", icm.Description)
@@ -347,22 +353,28 @@ func TestDoltTransactionCommitTwoClients(t *testing.T) {
 	require.NoError(t, err)
 	headRefs, err := db.GetHeadRefs(context.Background())
 	require.NoError(t, err)
-	commit2, err := db.Resolve(context.Background(), cs, headRefs[0])
+	optCmt, err := db.Resolve(context.Background(), cs, headRefs[0])
 	require.NoError(t, err)
+	commit2, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	cm2, err := commit2.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, cm2.Description, "ClientA Commit")
 
 	as, err := doltdb.NewAncestorSpec("~1")
 	require.NoError(t, err)
-	commit1, err := commit2.GetAncestor(context.Background(), as)
+	optCmt, err = commit2.GetAncestor(context.Background(), as)
 	require.NoError(t, err)
+	commit1, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	cm1, err := commit1.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, cm1.Description, "ClientB Commit")
 
-	commit0, err := commit1.GetAncestor(context.Background(), as)
+	optCmt, err = commit1.GetAncestor(context.Background(), as)
 	require.NoError(t, err)
+	commit0, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	cm0, err := commit0.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Equal(t, "checkpoint enginetest database mydb", cm0.Description)
@@ -427,22 +439,28 @@ func TestDoltTransactionCommitAutocommit(t *testing.T) {
 	require.NoError(t, err)
 	headRefs, err := db.GetHeadRefs(context.Background())
 	require.NoError(t, err)
-	head, err := db.Resolve(context.Background(), headSpec, headRefs[0])
+	optCmt, err := db.Resolve(context.Background(), headSpec, headRefs[0])
 	require.NoError(t, err)
+	head, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	headMeta, err := head.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, headMeta.Description, "ClientB Commit")
 
 	ancestorSpec, err := doltdb.NewAncestorSpec("~1")
 	require.NoError(t, err)
-	parent, err := head.GetAncestor(context.Background(), ancestorSpec)
+	optCmt, err = head.GetAncestor(context.Background(), ancestorSpec)
 	require.NoError(t, err)
+	parent, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	parentMeta, err := parent.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Contains(t, parentMeta.Description, "Transaction commit")
 
-	grandParent, err := parent.GetAncestor(context.Background(), ancestorSpec)
+	optCmt, err = parent.GetAncestor(context.Background(), ancestorSpec)
 	require.NoError(t, err)
+	grandParent, ok := optCmt.ToCommit()
+	require.True(t, ok)
 	grandparentMeta, err := grandParent.GetCommitMeta(context.Background())
 	require.NoError(t, err)
 	require.Equal(t, "checkpoint enginetest database mydb", grandparentMeta.Description)
