@@ -1617,9 +1617,9 @@ func createWorkingRootUpdate() map[string]TableUpdate {
 	}
 }
 
-func updateTables(t *testing.T, ctx context.Context, root *doltdb.RootValue, tblUpdates map[string]TableUpdate) *doltdb.RootValue {
+func updateTables(t *testing.T, ctx context.Context, root doltdb.RootValue, tblUpdates map[string]TableUpdate) doltdb.RootValue {
 	for tblName, updates := range tblUpdates {
-		tbl, ok, err := root.GetTable(ctx, tblName)
+		tbl, ok, err := root.GetTable(ctx, doltdb.TableName{Name: tblName})
 		require.NoError(t, err)
 
 		var sch schema.Schema
@@ -1664,7 +1664,7 @@ func updateTables(t *testing.T, ctx context.Context, root *doltdb.RootValue, tbl
 		tbl, err = doltdb.NewNomsTable(ctx, root.VRW(), root.NodeStore(), sch, rowData, indexData, nil)
 		require.NoError(t, err)
 
-		root, err = root.PutTable(ctx, tblName, tbl)
+		root, err = root.PutTable(ctx, doltdb.TableName{Name: tblName}, tbl)
 		require.NoError(t, err)
 	}
 
