@@ -29,8 +29,9 @@ import (
 
 // ParseCreateTableStatement will parse a CREATE TABLE ddl statement and use it to create a Dolt Schema. A RootValue
 // is used to generate unique tags for the Schema
-func ParseCreateTableStatement(ctx *sql.Context, root *doltdb.RootValue, engine *sqle.Engine, query string) (string, schema.Schema, error) {
-	parsed, err := planbuilder.Parse(ctx, engine.Analyzer.Catalog, query)
+func ParseCreateTableStatement(ctx *sql.Context, root doltdb.RootValue, engine *sqle.Engine, query string) (string, schema.Schema, error) {
+	binder := planbuilder.New(ctx, engine.Analyzer.Catalog, engine.Parser)
+	parsed, _, _, err := binder.Parse(query, false)
 	if err != nil {
 		return "", nil, err
 	}
