@@ -44,7 +44,7 @@ type TempTable struct {
 
 	lookup sql.IndexLookup
 
-	ed   writer.TableWriter
+	ed   dsess.TableWriter
 	opts editor.Options
 }
 
@@ -103,7 +103,7 @@ func NewTempTable(
 		return nil, err
 	}
 
-	newRoot, err := ws.WorkingRoot().PutTable(ctx, name, tbl)
+	newRoot, err := ws.WorkingRoot().PutTable(ctx, doltdb.TableName{Name: name}, tbl)
 	if err != nil {
 		return nil, err
 	}
@@ -126,7 +126,7 @@ func NewTempTable(
 		opts:      opts,
 	}
 
-	tempTable.ed, err = writeSession.GetTableWriter(ctx, name, db, setTempTableRoot(tempTable))
+	tempTable.ed, err = writeSession.GetTableWriter(ctx, doltdb.TableName{Name: name}, db, setTempTableRoot(tempTable))
 	if err != nil {
 		return nil, err
 	}
@@ -134,9 +134,9 @@ func NewTempTable(
 	return tempTable, nil
 }
 
-func setTempTableRoot(t *TempTable) func(ctx *sql.Context, dbName string, newRoot *doltdb.RootValue) error {
-	return func(ctx *sql.Context, dbName string, newRoot *doltdb.RootValue) error {
-		newTable, _, err := newRoot.GetTable(ctx, t.tableName)
+func setTempTableRoot(t *TempTable) func(ctx *sql.Context, dbName string, newRoot doltdb.RootValue) error {
+	return func(ctx *sql.Context, dbName string, newRoot doltdb.RootValue) error {
+		newTable, _, err := newRoot.GetTable(ctx, doltdb.TableName{Name: t.tableName})
 		if err != nil {
 			return err
 		}
@@ -166,7 +166,7 @@ func setTempTableRoot(t *TempTable) func(ctx *sql.Context, dbName string, newRoo
 		}
 
 		writeSession := writer.NewWriteSession(newTable.Format(), newWs, ait, t.opts)
-		t.ed, err = writeSession.GetTableWriter(ctx, t.tableName, t.dbName, setTempTableRoot(t))
+		t.ed, err = writeSession.GetTableWriter(ctx, doltdb.TableName{Name: t.tableName}, t.dbName, setTempTableRoot(t))
 		if err != nil {
 			return err
 		}
