@@ -24,6 +24,7 @@ import (
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/globalstate"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/index"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlutil"
@@ -31,33 +32,6 @@ import (
 	"github.com/dolthub/dolt/go/store/types"
 )
 
-// WriteSession encapsulates writes made within a SQL session.
-// It's responsible for creating and managing the lifecycle of TableWriter's.
-type WriteSession interface {
-	// GetTableWriter creates a TableWriter and adds it to the WriteSession.
-	GetTableWriter(ctx *sql.Context, table, db string, setter SessionRootSetter) (TableWriter, error)
-
-	// SetWorkingSet modifies the state of the WriteSession. The WorkingSetRef of |ws| must match the existing Ref.
-	SetWorkingSet(ctx *sql.Context, ws *doltdb.WorkingSet) error
-
-	// GetOptions returns the editor.Options for this session.
-	GetOptions() editor.Options
-
-	// SetOptions sets the editor.Options for this session.
-	SetOptions(opts editor.Options)
-
-	WriteSessionFlusher
-}
-
-// WriteSessionFlusher is responsible for flushing any pending edits to the session
-type WriteSessionFlusher interface {
-	// Flush flushes the pending writes in the session.
-	Flush(ctx *sql.Context) (*doltdb.WorkingSet, error)
-	// FlushWithAutoIncrementOverrides flushes the pending writes in the session, overriding the auto increment values
-	// for any tables provided in the map
-	FlushWithAutoIncrementOverrides(ctx *sql.Context, increment bool, autoIncrements map[string]uint64) (*doltdb.WorkingSet, error)
-}
-
 // nomsWriteSession handles all edit operations on a table that may also update other tables.
 // Serves as coordination for SessionedTableEditors.
 type nomsWriteSession struct {
@@ -68,16 +42,16 @@ type nomsWriteSession struct {
 	opts       editor.Options
 }
 
-var _ WriteSession = &nomsWriteSession{}
+var _ dsess.WriteSession = &nomsWriteSession{}
 
 // NewWriteSession creates and returns a WriteSession. Inserting a nil root is not an error, as there are
-// locations that do not have a root at the time of this call. However, a root must be set through SetRoot before any
+// locations that do not have a root at the time of this call. However, a root must be set through SetWorkingRoot before any
 // table editors are returned.
-func NewWriteSession(nbf *types.NomsBinFormat, ws *doltdb.WorkingSet, aiTracker globalstate.AutoIncrementTracker, opts editor.Options) WriteSession {
+func NewWriteSession(nbf *types.NomsBinFormat, ws *doltdb.WorkingSet, aiTracker globalstate.AutoIncrementTracker, opts editor.Options) dsess.WriteSession {
 	if types.IsFormat_DOLT(nbf) {
 		return &prollyWriteSession{
 			workingSet: ws,
-			tables:     make(map[string]*prollyTableWriter),
+			tables:     make(map[doltdb.TableName]*prollyTableWriter),
 			aiTracker:  aiTracker,
 			mut:        &sync.RWMutex{},
 		}
@@ -92,7 +66,11 @@ func NewWriteSession(nbf *types.NomsBinFormat, ws *doltdb.WorkingSet, aiTracker
 	}
 }
 
-func (s *nomsWriteSession) GetTableWriter(ctx *sql.Context, table, db string, setter SessionRootSetter) (TableWriter, error) {
+func (s *nomsWriteSession) GetWorkingSet() *doltdb.WorkingSet {
+	return s.workingSet
+}
+
+func (s *nomsWriteSession) GetTableWriter(ctx *sql.Context, table doltdb.TableName, db string, setter dsess.SessionRootSetter) (dsess.TableWriter, error) {
 	s.mut.Lock()
 	defer s.mut.Unlock()
 
@@ -109,12 +87,12 @@ func (s *nomsWriteSession) GetTableWriter(ctx *sql.Context, table, db string, se
 	if err != nil {
 		return nil, err
 	}
-	sqlSch, err := sqlutil.FromDoltSchema("", table, sch)
+	sqlSch, err := sqlutil.FromDoltSchema("", table.Name, sch)
 	if err != nil {
 		return nil, err
 	}
 
-	te, err := s.getTableEditor(ctx, table, sch)
+	te, err := s.getTableEditor(ctx, table.Name, sch)
 	if err != nil {
 		return nil, err
 	}
@@ -122,7 +100,7 @@ func (s *nomsWriteSession) GetTableWriter(ctx *sql.Context, table, db string, se
 	conv := index.NewKVToSqlRowConverterForCols(t.Format(), sch, nil)
 
 	return &nomsTableWriter{
-		tableName:   table,
+		tableName:   table.Name,
 		dbName:      db,
 		sch:         sch,
 		sqlSch:      sqlSch.Schema,
@@ -170,7 +148,7 @@ func (s *nomsWriteSession) flush(ctx *sql.Context) (*doltdb.WorkingSet, error) {
 		mu.Lock()
 		defer mu.Unlock()
 		if newRoot != nil {
-			newRoot, err = newRoot.PutTable(ctx, name, table)
+			newRoot, err = newRoot.PutTable(ctx, doltdb.TableName{Name: name}, table)
 		}
 		return err
 	}
@@ -238,7 +216,7 @@ func (s *nomsWriteSession) getTableEditor(ctx context.Context, tableName string,
 
 	root := s.workingSet.WorkingRoot()
 
-	t, ok, err = root.GetTable(ctx, tableName)
+	t, ok, err = root.GetTable(ctx, doltdb.TableName{Name: tableName})
 	if err != nil {
 		return nil, err
 	}
@@ -262,7 +240,7 @@ func (s *nomsWriteSession) getTableEditor(ctx context.Context, tableName string,
 	return localTableEditor, nil
 }
 
-// setRoot is the inner implementation for SetRoot that does not acquire any locks
+// setRoot is the inner implementation for SetWorkingRoot that does not acquire any locks
 func (s *nomsWriteSession) setWorkingSet(ctx context.Context, ws *doltdb.WorkingSet) error {
 	if ws == nil {
 		return fmt.Errorf("cannot set a nomsWriteSession's working set to nil once it has been created")
@@ -274,7 +252,7 @@ func (s *nomsWriteSession) setWorkingSet(ctx context.Context, ws *doltdb.Working
 
 	root := ws.WorkingRoot()
 	for tableName, localTableEditor := range s.tables {
-		t, ok, err := root.GetTable(ctx, tableName)
+		t, ok, err := root.GetTable(ctx, doltdb.TableName{Name: tableName})
 		if err != nil {
 			return err
 		}
