@@ -15,7 +15,6 @@
 package writer
 
 import (
-	"context"
 	"sync"
 
 	"github.com/dolthub/go-mysql-server/sql"
@@ -23,8 +22,8 @@ import (
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/globalstate"
-	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlutil"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 )
 
@@ -32,23 +31,31 @@ import (
 // Serves as coordination for SessionedTableEditors.
 type prollyWriteSession struct {
 	workingSet *doltdb.WorkingSet
-	tables     map[string]*prollyTableWriter
+	tables     map[doltdb.TableName]*prollyTableWriter
 	aiTracker  globalstate.AutoIncrementTracker
 	mut        *sync.RWMutex
 }
 
-var _ WriteSession = &prollyWriteSession{}
+var _ dsess.WriteSession = &prollyWriteSession{}
+
+func (s *prollyWriteSession) GetWorkingSet() *doltdb.WorkingSet {
+	return s.workingSet
+}
 
 // GetTableWriter implemented WriteSession.
-func (s *prollyWriteSession) GetTableWriter(ctx *sql.Context, table, db string, setter SessionRootSetter) (TableWriter, error) {
+func (s *prollyWriteSession) GetTableWriter(ctx *sql.Context, tableName doltdb.TableName, db string, setter dsess.SessionRootSetter) (dsess.TableWriter, error) {
 	s.mut.Lock()
 	defer s.mut.Unlock()
 
-	if tw, ok := s.tables[table]; ok {
+	if tw, ok := s.tables[tableName]; ok {
 		return tw, nil
 	}
 
-	t, ok, err := s.workingSet.WorkingRoot().GetTable(ctx, table)
+	// XXX: certain table editors rely on this embedded working set. See
+	// fullTextRewriteEditor for one example, where the |ctx| maintains
+	// the old version of the data while fulltext indexes are rebuilt
+	// using this hidden empty workingSet.
+	t, ok, err := s.workingSet.WorkingRoot().GetTable(ctx, tableName)
 	if err != nil {
 		return nil, err
 	}
@@ -56,52 +63,47 @@ func (s *prollyWriteSession) GetTableWriter(ctx *sql.Context, table, db string,
 		return nil, doltdb.ErrTableNotFound
 	}
 
-	sch, err := t.GetSchema(ctx)
+	schState, err := writerSchema(ctx, t, tableName.Name, db)
 	if err != nil {
 		return nil, err
 	}
-	pkSch, err := sqlutil.FromDoltSchema("", table, sch)
-	if err != nil {
-		return nil, err
-	}
-	autoCol := autoIncrementColFromSchema(sch)
 
 	var pw indexWriter
 	var sws map[string]indexWriter
-	if schema.IsKeyless(sch) {
-		pw, err = getPrimaryKeylessProllyWriter(ctx, t, pkSch.Schema, sch)
+	if schema.IsKeyless(schState.DoltSchema) {
+		pw, err = getPrimaryKeylessProllyWriter(ctx, t, schState)
 		if err != nil {
 			return nil, err
 		}
-		sws, err = getSecondaryKeylessProllyWriters(ctx, t, pkSch.Schema, sch, pw.(prollyKeylessWriter))
+		sws, err = getSecondaryKeylessProllyWriters(ctx, t, schState, pw.(prollyKeylessWriter))
 		if err != nil {
 			return nil, err
 		}
 	} else {
-		pw, err = getPrimaryProllyWriter(ctx, t, pkSch.Schema, sch)
+		pw, err = getPrimaryProllyWriter(ctx, t, schState)
 		if err != nil {
 			return nil, err
 		}
-		sws, err = getSecondaryProllyIndexWriters(ctx, t, pkSch.Schema, sch)
+		sws, err = getSecondaryProllyIndexWriters(ctx, t, schState)
 		if err != nil {
 			return nil, err
 		}
 	}
 
 	twr := &prollyTableWriter{
-		tableName: table,
+		tableName: tableName,
 		dbName:    db,
 		primary:   pw,
 		secondary: sws,
 		tbl:       t,
-		sch:       sch,
-		sqlSch:    pkSch.Schema,
-		aiCol:     autoCol,
+		sch:       schState.DoltSchema,
+		sqlSch:    schState.PkSchema.Schema,
+		aiCol:     schState.AutoIncCol,
 		aiTracker: s.aiTracker,
 		flusher:   s,
 		setter:    setter,
 	}
-	s.tables[table] = twr
+	s.tables[tableName] = twr
 
 	return twr, nil
 }
@@ -138,7 +140,7 @@ func (s *prollyWriteSession) SetOptions(opts editor.Options) {
 
 // flush is the inner implementation for Flush that does not acquire any locks
 func (s *prollyWriteSession) flush(ctx *sql.Context, autoIncSet bool, manualAutoIncrementsSettings map[string]uint64) (*doltdb.WorkingSet, error) {
-	tables := make(map[string]*doltdb.Table, len(s.tables))
+	tables := make(map[doltdb.TableName]*doltdb.Table, len(s.tables))
 	mu := &sync.Mutex{}
 
 	eg, egCtx := errgroup.WithContext(ctx)
@@ -156,8 +158,9 @@ func (s *prollyWriteSession) flush(ctx *sql.Context, autoIncSet bool, manualAuto
 			// Update this table's auto increment value if it has one. This value comes from the global state unless an
 			// override was specified (e.g. if the next value was set explicitly)
 			if schema.HasAutoIncrement(wr.sch) {
-				autoIncVal := s.aiTracker.Current(name)
-				override, hasManuallySetAi := manualAutoIncrementsSettings[name]
+				// TODO: need schema name for auto increment
+				autoIncVal := s.aiTracker.Current(name.Name)
+				override, hasManuallySetAi := manualAutoIncrementsSettings[name.Name]
 				if hasManuallySetAi {
 					autoIncVal = override
 				}
@@ -165,7 +168,7 @@ func (s *prollyWriteSession) flush(ctx *sql.Context, autoIncSet bool, manualAuto
 				// Update the table with the new auto-inc value if necessary. If it was set manually via an ALTER TABLE
 				// statement, we defer to the tracker to update the value itself, since this impacts the global state.
 				if hasManuallySetAi {
-					t, err = s.aiTracker.Set(sqlEgCtx, name, t, s.workingSet.Ref(), autoIncVal)
+					t, err = s.aiTracker.Set(sqlEgCtx, name.Name, t, s.workingSet.Ref(), autoIncVal)
 					if err != nil {
 						return err
 					}
@@ -201,8 +204,8 @@ func (s *prollyWriteSession) flush(ctx *sql.Context, autoIncSet bool, manualAuto
 	return s.workingSet, nil
 }
 
-// setRoot is the inner implementation for SetRoot that does not acquire any locks
-func (s *prollyWriteSession) setWorkingSet(ctx context.Context, ws *doltdb.WorkingSet) error {
+// setRoot is the inner implementation for SetWorkingRoot that does not acquire any locks
+func (s *prollyWriteSession) setWorkingSet(ctx *sql.Context, ws *doltdb.WorkingSet) error {
 	root := ws.WorkingRoot()
 	for tableName, tableWriter := range s.tables {
 		t, ok, err := root.GetTable(ctx, tableName)
