@@ -30,6 +30,7 @@ import (
 	srv "github.com/dolthub/dolt/go/cmd/dolt/commands/sqlserver"
 	"github.com/dolthub/dolt/go/libraries/doltcore/dtestutils/testcommands"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
+	"github.com/dolthub/dolt/go/libraries/doltcore/servercfg"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
 	"github.com/dolthub/dolt/go/libraries/utils/svcs"
 )
@@ -75,7 +76,7 @@ func BenchmarkPushOnWrite(b *testing.B) {
 
 func benchmarkServer(b *testing.B, test serverTest) {
 	var dEnv *env.DoltEnv
-	var cfg srv.ServerConfig
+	var cfg servercfg.ServerConfig
 	ctx := context.Background()
 
 	// setup
@@ -109,7 +110,7 @@ const (
 	email = "name@fake.horse"
 )
 
-func getEnvAndConfig(ctx context.Context, b *testing.B) (dEnv *env.DoltEnv, cfg srv.ServerConfig) {
+func getEnvAndConfig(ctx context.Context, b *testing.B) (dEnv *env.DoltEnv, cfg servercfg.ServerConfig) {
 	multiSetup := testcommands.NewMultiRepoTestSetup(b.Fatal)
 
 	multiSetup.NewDB("dolt_bench")
@@ -145,7 +146,7 @@ listener:
  write_timeout_millis: 28800000
 `, writerName, multiSetup.DbPaths[writerName], port))
 
-	cfg, err := srv.NewYamlConfig(yaml)
+	cfg, err := servercfg.NewYamlConfig(yaml)
 	if err != nil {
 		b.Fatal(err)
 	}
@@ -163,7 +164,7 @@ func getProfFile(b *testing.B) *os.File {
 	return f
 }
 
-func executeServerQueries(ctx context.Context, b *testing.B, dEnv *env.DoltEnv, cfg srv.ServerConfig, queries []query) {
+func executeServerQueries(ctx context.Context, b *testing.B, dEnv *env.DoltEnv, cfg servercfg.ServerConfig, queries []query) {
 	sc := svcs.NewController()
 
 	eg, ctx := errgroup.WithContext(ctx)
@@ -198,8 +199,8 @@ func executeServerQueries(ctx context.Context, b *testing.B, dEnv *env.DoltEnv,
 	}
 }
 
-func executeQuery(cfg srv.ServerConfig, q query) error {
-	cs := srv.ConnectionString(cfg, database)
+func executeQuery(cfg servercfg.ServerConfig, q query) error {
+	cs := servercfg.ConnectionString(cfg, database)
 	conn, err := dbr.Open("mysql", cs, nil)
 	if err != nil {
 		return err
