@@ -55,7 +55,17 @@ const (
 
 var ErrNothingToCollect = errors.New("no changes since last gc")
 
-type GetAddrsCb func(ctx context.Context, c Chunk) (hash.HashSet, error)
+// GetAddrsCurry returns a function that will add a chunk's child
+// references to a HashSet. The intermediary lets us build a single
+// HashSet per memTable.
+type GetAddrsCurry func(c Chunk) GetAddrsCb
+
+// GetAddrsCb adds the refs for a pre-specified chunk to |addrs|
+type GetAddrsCb func(ctx context.Context, addrs hash.HashSet, exists PendingRefExists) error
+
+type PendingRefExists func(hash.Hash) bool
+
+func NoopPendingRefExists(_ hash.Hash) bool { return false }
 
 // ChunkStore is the core storage abstraction in noms. We can put data
 // anyplace we have a ChunkStore implementation for.
@@ -82,7 +92,7 @@ type ChunkStore interface {
 	// to Flush(). Put may be called concurrently with other calls to Put(),
 	// Get(), GetMany(), Has() and HasMany(). Will return an error if the
 	// addrs returned by `getAddrs` are absent from the chunk store.
-	Put(ctx context.Context, c Chunk, getAddrs GetAddrsCb) error
+	Put(ctx context.Context, c Chunk, getAddrs GetAddrsCurry) error
 
 	// Returns the NomsBinFormat with which this ChunkSource is compatible.
 	Version() string
@@ -113,6 +123,12 @@ type ChunkStore interface {
 	// supported.
 	StatsSummary() string
 
+	// PersistGhostHashes is used to persist a set of addresses that are known to exist, but
+	// are not currently stored here. Only the GenerationalChunkStore implementation allows use of this method, as
+	// shallow clones are only allowed in local copies currently. Note that at the application level, the only
+	// hashes which can be ghosted are commit ids, but the chunk store doesn't know what those are.
+	PersistGhostHashes(ctx context.Context, refs hash.HashSet) error
+
 	// Close tears down any resources in use by the implementation. After
 	// Close(), the ChunkStore may not be used again. It is NOT SAFE to call
 	// Close() concurrently with any other ChunkStore method; behavior is
@@ -156,7 +172,7 @@ type ChunkStoreGarbageCollector interface {
 	BeginGC(addChunk func(hash.Hash) bool) error
 
 	// EndGC indicates that the GC is over. The previously provided
-	// addChunk function must not be called after this function function.
+	// addChunk function must not be called after this function.
 	EndGC()
 
 	// MarkAndSweepChunks is expected to read chunk addresses off of
@@ -182,6 +198,7 @@ type PrefixChunkStore interface {
 type GenerationalCS interface {
 	NewGen() ChunkStoreGarbageCollector
 	OldGen() ChunkStoreGarbageCollector
+	GhostGen() ChunkStore
 }
 
 var ErrUnsupportedOperation = errors.New("operation not supported")
