@@ -74,6 +74,11 @@ func (c *Commit) NomsValue() types.Value {
 	return c.val
 }
 
+func (c *Commit) IsGhost() bool {
+	_, ok := c.val.(types.GhostValue)
+	return ok
+}
+
 func (c *Commit) Height() uint64 {
 	return c.height
 }
@@ -306,6 +311,10 @@ func commitPtr(nbf *types.NomsBinFormat, v types.Value, r *types.Ref) (*Commit,
 
 // CommitFromValue deserializes a types.Value into a Commit.
 func CommitFromValue(nbf *types.NomsBinFormat, v types.Value) (*Commit, error) {
+	if g, ok := v.(types.GhostValue); ok {
+		return &Commit{val: g}, nil
+	}
+
 	isCommit, err := IsCommit(v)
 	if err != nil {
 		return nil, err
@@ -448,6 +457,12 @@ func FindClosureCommonAncestor(ctx context.Context, cl CommitClosure, cm *Commit
 
 // GetCommitParents returns |Ref|s to the parents of the commit.
 func GetCommitParents(ctx context.Context, vr types.ValueReader, cv types.Value) ([]*Commit, error) {
+	_, ok := cv.(types.GhostValue)
+	if ok {
+		// Not using the common error here because they are in the doltdb package which results in a cycle.
+		return nil, fmt.Errorf("runtime exception. GetCommitParents called with GhostCommit.")
+	}
+
 	if sm, ok := cv.(types.SerialMessage); ok {
 		data := []byte(sm)
 		if serial.GetFileID(data) != serial.CommitFileID {
@@ -457,6 +472,7 @@ func GetCommitParents(ctx context.Context, vr types.ValueReader, cv types.Value)
 		if err != nil {
 			return nil, err
 		}
+
 		vals, err := vr.ReadManyValues(ctx, addrs)
 		if err != nil {
 			return nil, err
@@ -466,19 +482,28 @@ func GetCommitParents(ctx context.Context, vr types.ValueReader, cv types.Value)
 			if v == nil {
 				return nil, fmt.Errorf("GetCommitParents: Did not find parent Commit in ValueReader: %s", addrs[i].String())
 			}
-			var csm serial.Commit
-			err := serial.InitCommitRoot(&csm, []byte(v.(types.SerialMessage)), serial.MessagePrefixSz)
-			if err != nil {
-				return nil, err
-			}
-			res[i] = &Commit{
-				val:    v,
-				height: csm.Height(),
-				addr:   addrs[i],
+
+			if g, ok := v.(types.GhostValue); ok {
+				res[i] = &Commit{
+					val:  g,
+					addr: addrs[i],
+				}
+			} else {
+				var csm serial.Commit
+				err := serial.InitCommitRoot(&csm, []byte(v.(types.SerialMessage)), serial.MessagePrefixSz)
+				if err != nil {
+					return nil, err
+				}
+				res[i] = &Commit{
+					val:    v,
+					height: csm.Height(),
+					addr:   addrs[i],
+				}
 			}
 		}
 		return res, nil
 	}
+
 	c, ok := cv.(types.Struct)
 	if !ok {
 		return nil, errors.New("GetCommitParents: provided value is not a commit.")
@@ -626,12 +651,12 @@ func GetCommitRootHash(cv types.Value) (hash.Hash, error) {
 }
 
 func parentsToQueue(ctx context.Context, commits []*Commit, q *CommitByHeightHeap, vr types.ValueReader) error {
-	seen := make(map[hash.Hash]bool)
+	seen := make(map[hash.Hash]struct{})
 	for _, c := range commits {
 		if _, ok := seen[c.Addr()]; ok {
 			continue
 		}
-		seen[c.Addr()] = true
+		seen[c.Addr()] = struct{}{}
 
 		parents, err := GetCommitParents(ctx, vr, c.NomsValue())
 		if err != nil {
