@@ -34,7 +34,7 @@ const (
 	tagMetaVersion = "1.0"
 )
 
-var TagNowFunc = CommitNowFunc
+var TagNowFunc = CommitterDate
 var TagLoc = CommitLoc
 
 // TagMeta contains all the metadata that is associated with a tag within a data repo.
