@@ -14,7 +14,9 @@
 
 package nbs
 
-import "github.com/dolthub/dolt/go/store/d"
+import (
+	"github.com/dolthub/dolt/go/store/d"
+)
 
 func mustUint32(val uint32, err error) uint32 {
 	d.PanicIfError(err)
@@ -25,8 +27,3 @@ func mustUint64(val uint64, err error) uint64 {
 	d.PanicIfError(err)
 	return val
 }
-
-func mustAddr(h addr, err error) addr {
-	d.PanicIfError(err)
-	return h
-}
