@@ -54,7 +54,7 @@ func (sm SerialMessage) Hash(nbf *NomsBinFormat) (hash.Hash, error) {
 }
 
 func (sm SerialMessage) HumanReadableString() string {
-	return sm.humanReadableStringAtIndentationLevel(0)
+	return sm.HumanReadableStringAtIndentationLevel(0)
 }
 
 func printWithIndendationLevel(level int, builder *strings.Builder, format string, a ...any) {
@@ -62,7 +62,7 @@ func printWithIndendationLevel(level int, builder *strings.Builder, format strin
 	fmt.Fprintf(builder, format, a...)
 }
 
-func (sm SerialMessage) humanReadableStringAtIndentationLevel(level int) string {
+func (sm SerialMessage) HumanReadableStringAtIndentationLevel(level int) string {
 	id := serial.GetFileID(sm)
 	switch id {
 	// NOTE: splunk uses a separate path for some printing
@@ -72,14 +72,14 @@ func (sm SerialMessage) humanReadableStringAtIndentationLevel(level int) string
 		ret := &strings.Builder{}
 		mapbytes := msg.AddressMapBytes()
 		printWithIndendationLevel(level, ret, "StoreRoot{%s}",
-			SerialMessage(mapbytes).humanReadableStringAtIndentationLevel(level+1))
+			SerialMessage(mapbytes).HumanReadableStringAtIndentationLevel(level+1))
 		return ret.String()
 	case serial.StashListFileID:
 		msg, _ := serial.TryGetRootAsStashList([]byte(sm), serial.MessagePrefixSz)
 		ret := &strings.Builder{}
 		mapbytes := msg.AddressMapBytes()
 		printWithIndendationLevel(level, ret, "StashList{%s}",
-			SerialMessage(mapbytes).humanReadableStringAtIndentationLevel(level+1))
+			SerialMessage(mapbytes).HumanReadableStringAtIndentationLevel(level+1))
 		return ret.String()
 	case serial.StashFileID:
 		msg, _ := serial.TryGetRootAsStash(sm, serial.MessagePrefixSz)
@@ -165,9 +165,11 @@ func (sm SerialMessage) humanReadableStringAtIndentationLevel(level int) string
 		printWithIndendationLevel(level, ret, "\tFeatureVersion: %d\n", msg.FeatureVersion())
 		printWithIndendationLevel(level, ret, "\tForeignKeys: #%s\n", hash.New(msg.ForeignKeyAddrBytes()).String())
 		printWithIndendationLevel(level, ret, "\tTables: %s\n",
-			SerialMessage(msg.TablesBytes()).humanReadableStringAtIndentationLevel(level+1))
+			SerialMessage(msg.TablesBytes()).HumanReadableStringAtIndentationLevel(level+1))
 		printWithIndendationLevel(level, ret, "}")
 		return ret.String()
+	case serial.DoltgresRootValueFileID:
+		return DoltgresRootValueHumanReadableStringAtIndentationLevel(sm, level)
 	case serial.TableFileID:
 		msg, _ := serial.TryGetRootAsTable(sm, serial.MessagePrefixSz)
 		ret := &strings.Builder{}
@@ -181,7 +183,7 @@ func (sm SerialMessage) humanReadableStringAtIndentationLevel(level int) string
 
 		printWithIndendationLevel(level, ret, "\tPrimary index: #%s\n", hash.Of(msg.PrimaryIndexBytes()))
 		printWithIndendationLevel(level, ret, "\tSecondary indexes: %s\n",
-			SerialMessage(msg.SecondaryIndexesBytes()).humanReadableStringAtIndentationLevel(level+1))
+			SerialMessage(msg.SecondaryIndexesBytes()).HumanReadableStringAtIndentationLevel(level+1))
 		printWithIndendationLevel(level, ret, "}")
 		return ret.String()
 	case serial.AddressMapFileID:
@@ -399,6 +401,11 @@ func (sm SerialMessage) WalkAddrs(nbf *NomsBinFormat, cb func(addr hash.Hash) er
 				return err
 			}
 		}
+	case serial.DoltgresRootValueFileID:
+		if !nbf.UsesFlatbuffers() {
+			return fmt.Errorf("root values for Doltgres only use flatbuffer serialization")
+		}
+		return DoltgresRootValueWalkAddrs(sm, cb)
 	case serial.TableFileID:
 		var msg serial.Table
 		err := serial.InitTableRoot(&msg, []byte(sm), serial.MessagePrefixSz)
@@ -541,3 +548,15 @@ func (sm SerialMessage) writeTo(w nomsWriter, nbf *NomsBinFormat) error {
 func (sm SerialMessage) valueReadWriter() ValueReadWriter {
 	return nil
 }
+
+// DoltgresRootValueHumanReadableStringAtIndentationLevel returns the human readable string at the given indentation
+// level for root values. This is a variable as it's changed in Doltgres.
+var DoltgresRootValueHumanReadableStringAtIndentationLevel = func(sm SerialMessage, level int) string {
+	return "DOLTGRES ROOT VALUE"
+}
+
+// DoltgresRootValueWalkAddrs walks the given message using the given callback. This is a variable as it's changed in
+// Doltgres.
+var DoltgresRootValueWalkAddrs = func(sm SerialMessage, cb func(addr hash.Hash) error) error {
+	return fmt.Errorf("cannot walk a Doltgres root value from within Dolt")
+}
