@@ -102,8 +102,10 @@ func (f *FileValueStore) WriteValue(ctx context.Context, v types.Value) (types.R
 			return types.Ref{}, err
 		}
 
-		err = f.Put(ctx, c, func(ctx context.Context, c chunks.Chunk) (hash.HashSet, error) {
-			return types.AddrsFromNomsValue(ctx, c, f.nbf)
+		err = f.Put(ctx, c, func(c chunks.Chunk) chunks.GetAddrsCb {
+			return func(ctx context.Context, addrs hash.HashSet, _ chunks.PendingRefExists) error {
+				return types.AddrsFromNomsValue(c, f.nbf, addrs)
+			}
 		})
 
 		if err != nil {
@@ -154,6 +156,11 @@ func (f *FileValueStore) Has(ctx context.Context, h hash.Hash) (bool, error) {
 	return ok, nil
 }
 
+func (f *FileValueStore) CacheHas(h hash.Hash) bool {
+	_, ok := f.chunks[h]
+	return ok
+}
+
 // HasMany returns the set of hashes that are absent from the store
 func (f *FileValueStore) HasMany(ctx context.Context, hashes hash.HashSet) (absent hash.HashSet, err error) {
 	f.chunkLock.Lock()
@@ -184,8 +191,9 @@ func (f *FileValueStore) errorIfDangling(ctx context.Context, addrs hash.HashSet
 }
 
 // Put puts a chunk into the store
-func (f *FileValueStore) Put(ctx context.Context, c chunks.Chunk, getAddrs chunks.GetAddrsCb) error {
-	addrs, err := getAddrs(ctx, c)
+func (f *FileValueStore) Put(ctx context.Context, c chunks.Chunk, getAddrs chunks.GetAddrsCurry) error {
+	addrs := hash.NewHashSet()
+	err := getAddrs(c)(ctx, addrs, f.CacheHas)
 	if err != nil {
 		return err
 	}
@@ -287,3 +295,8 @@ func (f *FileValueStore) iterChunks(cb func(ch chunks.Chunk) error) error {
 
 	return nil
 }
+
+func (f *FileValueStore) PersistGhostHashes(ctx context.Context, refs hash.HashSet) error {
+	// Current unimplemented, but may be useful for testing someday.
+	panic("not implemented")
+}
